@@ -27,6 +27,7 @@ class GerberaConan(ConanFile):
         "matroska": [True, False],
         "mysql": [True, False],
         "ffmpeg": [True, False],
+        "icu": [True, False],
         "ffmpegthumbnailer": [True, False],
     }
     default_options = {
@@ -42,15 +43,17 @@ class GerberaConan(ConanFile):
         "matroska": True,
         "mysql": True,
         "ffmpeg": True,
+        "icu": True,
         "ffmpegthumbnailer": True,
     }
 
     scm = {"type": "git", "url": "auto", "revision": "auto"}
 
     requires = [
-        "fmt/10.2.1", # spdlog/1.14.1 set this version
-        "spdlog/1.14.1",
+        "fmt/11.1.3", # spdlog/1.15.1 set this version
+        "spdlog/1.15.1",
         "pugixml/1.14",
+        "jsoncpp/[>=1.9.6]",
         "libiconv/[>=1.16]",
         "sqlite3/[>=3.35.5]",
         "zlib/1.3.1",
@@ -96,6 +99,9 @@ class GerberaConan(ConanFile):
         if self._needs_system_uuid:
             self.requires("libuuid/1.0.3")
 
+        if self.options.icu:
+            self.requires("icu/76.1")
+
     def system_requirements(self):
         if cross_building(self):
             self.output.info("Cross-compiling, not installing system packages")
@@ -149,6 +155,7 @@ class GerberaConan(ConanFile):
         tc.cache_variables["WITH_EXIV2"] = self.options.exiv2
         tc.cache_variables["WITH_MATROSKA"] = self.options.matroska
         tc.cache_variables["WITH_MYSQL"] = self.options.mysql
+        tc.cache_variables["WITH_ICU"] = self.options.icu
         tc.cache_variables["WITH_AVCODEC"] = self.options.ffmpeg
         tc.cache_variables["WITH_FFMPEGTHUMBNAILER"] = self.options.ffmpegthumbnailer
 
