@@ -1,11 +1,33 @@
-import {Auth} from '../../../web/js/gerbera-auth.module';
-import {Autoscan} from '../../../web/js/gerbera-autoscan.module';
-import {GerberaApp} from '../../../web/js/gerbera-app.module';
-import {Items} from '../../../web/js/gerbera-items.module';
-import {Menu} from '../../../web/js/gerbera-menu.module';
-import {Trail} from '../../../web/js/gerbera-trail.module';
-import {Tree} from '../../../web/js/gerbera-tree.module';
-import {Updates} from '../../../web/js/gerbera-updates.module';
+/*GRB*
+
+    Gerbera - https://gerbera.io/
+
+    gerbera.app.spec.js - this file is part of Gerbera.
+
+    Copyright (C) 2016-2025 Gerbera Contributors
+
+    Gerbera is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License version 2
+    as published by the Free Software Foundation.
+
+    Gerbera is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Gerbera.  If not, see <http://www.gnu.org/licenses/>.
+
+    $Id$
+*/
+import { Auth } from '../../../web/js/gerbera-auth.module';
+import { Autoscan } from '../../../web/js/gerbera-autoscan.module';
+import { GerberaApp } from '../../../web/js/gerbera-app.module';
+import { Items } from '../../../web/js/gerbera-items.module';
+import { Menu } from '../../../web/js/gerbera-menu.module';
+import { Trail } from '../../../web/js/gerbera-trail.module';
+import { Tree } from '../../../web/js/gerbera-tree.module';
+import { Updates } from '../../../web/js/gerbera-updates.module';
 
 import convertedConfig from './fixtures/converted-config';
 import mockConfig from './fixtures/config';
@@ -15,11 +37,11 @@ describe('Gerbera UI App', () => {
   let lsSpy;
   beforeEach(() => {
     lsSpy = spyOn(window.localStorage, 'getItem').and.callFake((name) => {
-        return;
+      return;
     });
   });
   beforeAll(() => {
-    spyOn(GerberaApp, 'writeLocalStorage').and.callFake(() => {});
+    spyOn(GerberaApp, 'writeLocalStorage').and.callFake(() => { });
   });
 
   describe('initialize()', () => {
@@ -62,6 +84,8 @@ describe('Gerbera UI App', () => {
         return $.Deferred().resolve(mockConfig).promise();
       });
 
+      if (GerberaApp.serverConfig)
+        GerberaApp.serverConfig.fsAddItem = false;
       await GerberaApp.initialize();
       var data = {
         req_type: 'auth',
@@ -69,22 +93,22 @@ describe('Gerbera UI App', () => {
       };
       data[Auth.SID] = 'A_MOCK_SID';
 
-      expect(ajaxSpy.calls.first().args[0]['url']).toEqual('content/interface');
+      expect(ajaxSpy.calls.first().args[0]['url']).toEqual('interface');
       expect(ajaxSpy.calls.first().args[0]['data']).toEqual(data);
 
       expect(GerberaApp.serverConfig).toEqual(convertedConfig.config);
       expect(Auth.checkSID).toHaveBeenCalled();
       expect(Updates.initialize).toHaveBeenCalled();
       expect(Menu.initialize).toHaveBeenCalledWith(GerberaApp.serverConfig);
-      expect($(document).attr('title')).toBe('Gerbera Media Server | Gerbera Media Server');
+      expect($(document).attr('title')).toBe('Wombat | Gerbera Media Server');
     });
 
     it('reports an error when the ajax calls fails', async () => {
       spyOn(Updates, 'showMessage');
 
       ajaxSpy.and.callFake(() => {
-        return Promise.reject({responseText: 'Internal Server Error'});
-        });
+        return Promise.reject({ responseText: 'Internal Server Error' });
+      });
 
       await GerberaApp.initialize();
       expect(Updates.showMessage).toHaveBeenCalledWith('Internal Server Error', undefined, 'info', 'fa-exclamation-triangle');
@@ -185,7 +209,7 @@ describe('Gerbera UI App', () => {
     });
     it('shows the event as error message when event has responseText', () => {
       spyOn(Updates, 'showMessage');
-      const event = {responseText : 'Response Text Error'};
+      const event = { responseText: 'Response Text Error' };
       GerberaApp.error(event);
 
       expect(Updates.showMessage).toHaveBeenCalledWith('Response Text Error', undefined, 'info', 'fa-exclamation-triangle');
@@ -247,8 +271,8 @@ describe('Gerbera UI App', () => {
       expect(result).toBeUndefined();
     });
     it('allows to be set with object data', () => {
-      GerberaApp.currentTreeItem = {test: 'test'};
-      expect(GerberaApp.currentTreeItem).toEqual({test: 'test'});
+      GerberaApp.currentTreeItem = { test: 'test' };
+      expect(GerberaApp.currentTreeItem).toEqual({ test: 'test' });
     });
   });
 
