@@ -1,3 +1,26 @@
+/*GRB*
+
+    Gerbera - https://gerbera.io/
+
+    gerbera.config.spec.js - this file is part of Gerbera.
+
+    Copyright (C) 2016-2025 Gerbera Contributors
+
+    Gerbera is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License version 2
+    as published by the Free Software Foundation.
+
+    Gerbera is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Gerbera.  If not, see <http://www.gnu.org/licenses/>.
+
+    $Id$
+*/
+/* global fixture */
 import { GerberaApp } from "../../../web/js/gerbera-app.module";
 import { Config } from '../../../web/js/gerbera-config.module';
 import mockConfig from './fixtures/config';
