@@ -1,10 +1,33 @@
-const { expect } = require('chai');
-const TestUtils = require('./page/test-utils');
-let driver;
+/*GRB*
 
+    Gerbera - https://gerbera.io/
+
+    items.spec.js - this file is part of Gerbera.
+
+    Copyright (C) 2016-2025 Gerbera Contributors
+
+    Gerbera is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License version 2
+    as published by the Free Software Foundation.
+
+    Gerbera is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Gerbera.  If not, see <http://www.gnu.org/licenses/>.
+
+    $Id$
+*/
+const { expect } = require('chai');
+
+const TestUtils = require('./page/test-utils');
 const HomePage = require('./page/home.page');
 const LoginPage = require('./page/login.page');
 
+let driver;
+
 describe('Items Suite', () => {
   let loginPage, homePage;
 
