@@ -3,7 +3,7 @@
 #
 # install-ebml.sh - this file is part of Gerbera.
 #
-# Copyright (C) 2021-2024 Gerbera Contributors
+# Copyright (C) 2021-2025 Gerbera Contributors
 #
 # Gerbera is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2
@@ -20,14 +20,15 @@
 # $Id$
 set -Eeuo pipefail
 
-. $(dirname "${BASH_SOURCE[0]}")/versions.sh
+main_dir=$(dirname "${BASH_SOURCE[0]}")
+main_dir=$(realpath "${main_dir}")/
+. ${main_dir}/gerbera-install-shell.sh
+. ${main_dir}/versions.sh
 
 VERSION="${EBML-1.4.2}"
 
-#script_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &>/dev/null && pwd -P)
-script_dir=`pwd -P`
-src_dir="${script_dir}/libebml-${VERSION}"
-tgz_file="${script_dir}/libebml-${VERSION}.tar.gz"
+setFiles libebml tar.gz
+source_files+=("https://github.com/Matroska-Org/libebml/archive/refs/tags/release-${VERSION}.tar.gz")
 
 BUILD_SHARED=YES
 
@@ -37,9 +38,9 @@ if [ $# -gt 0 ]; then
     fi
 fi
 
-downloadSource https://github.com/Matroska-Org/libebml/archive/refs/tags/release-${VERSION}.tar.gz
+downloadSource
 
-cmake .. -DBUILD_SHARED_LIBS=${BUILD_SHARED}
+cmake .. -DBUILD_SHARED_LIBS=${BUILD_SHARED} -DCMAKE_POLICY_VERSION_MINIMUM=3.5
 
 makeInstall
 
