@@ -3,7 +3,7 @@
 #
 # install-ffmpegthumbnailer.sh - this file is part of Gerbera.
 #
-# Copyright (C) 2018-2024 Gerbera Contributors
+# Copyright (C) 2018-2025 Gerbera Contributors
 #
 # Gerbera is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2
@@ -22,16 +22,23 @@ set -Eeuo pipefail
 
 main_dir=$(dirname "${BASH_SOURCE[0]}")
 main_dir=$(realpath "${main_dir}")/
+. ${main_dir}/gerbera-install-shell.sh
 . ${main_dir}/versions.sh
 
-COMMIT="${FFMPEGTHUMBNAILER_commit-0}"
 VERSION="${FFMPEGTHUMBNAILER-2.2.2}"
+COMMIT="${FFMPEGTHUMBNAILER_commit:-}"
 
-script_dir=`pwd -P`
-src_dir="${script_dir}/ffmpegthumbnailer-${VERSION}"
-tgz_file="${script_dir}/ffmpegthumbnailer-${VERSION}.tgz"
+src_file="https://github.com/dirkvdb/ffmpegthumbnailer/archive/refs/tags/${VERSION}.tar.gz"
 
-downloadSource https://github.com/dirkvdb/ffmpegthumbnailer/archive/${COMMIT}.tar.gz https://github.com/dirkvdb/ffmpegthumbnailer/archive/refs/tags/${VERSION}.tar.gz
+if [ -n "${COMMIT}" ]; then
+    source_files+=("https://github.com/dirkvdb/ffmpegthumbnailer/archive/${COMMIT}.tar.gz")
+    VERSION+="-"
+    VERSION+=`echo $COMMIT | cut -c 1-6`
+fi
+setFiles ffmpegthumbnailer tgz
+source_files+=("${src_file}")
+
+downloadSource
 
 installDeps ${main_dir} ffmpegthumbnailer
 
