@@ -3,7 +3,7 @@
 #
 # install-googletest.sh - this file is part of Gerbera.
 #
-# Copyright (C) 2018-2024 Gerbera Contributors
+# Copyright (C) 2018-2025 Gerbera Contributors
 #
 # Gerbera is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2
@@ -20,16 +20,19 @@
 # $Id$
 set -Eeuo pipefail
 
-. $(dirname "${BASH_SOURCE[0]}")/versions.sh
+main_dir=$(dirname "${BASH_SOURCE[0]}")
+main_dir=$(realpath "${main_dir}")/
+. ${main_dir}/gerbera-install-shell.sh
+. ${main_dir}/versions.sh
 
 VERSION="${GOOGLETEST-1.11.0}"
 
-script_dir=`pwd -P`
-src_dir="${script_dir}/gtest-${VERSION}"
-tgz_file="${script_dir}/gtest-${VERSION}.tgz"
+setFiles gtest tgz
+source_files+=("https://github.com/google/googletest/archive/refs/tags/v${VERSION}.tar.gz")
+source_files+=("https://github.com/google/googletest/archive/refs/tags/release-${VERSION}.tar.gz")
 
 ## Download GoogleTest from GitHub
-downloadSource https://github.com/google/googletest/archive/refs/tags/release-${VERSION}.tar.gz https://github.com/google/googletest/archive/refs/tags/v${VERSION}.tar.gz
+downloadSource
 
 cmake -DCMAKE_CXX_FLAGS="${CMAKE_CXX_FLAGS:-} -std=c++17" -DBUILD_GMOCK=1 ..
 
