@@ -3,7 +3,7 @@
 #
 # install-matroska.sh - this file is part of Gerbera.
 #
-# Copyright (C) 2018-2024 Gerbera Contributors
+# Copyright (C) 2018-2025 Gerbera Contributors
 #
 # Gerbera is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2
@@ -20,13 +20,15 @@
 # $Id$
 set -Eeuo pipefail
 
-. $(dirname "${BASH_SOURCE[0]}")/versions.sh
+main_dir=$(dirname "${BASH_SOURCE[0]}")
+main_dir=$(realpath "${main_dir}")/
+. ${main_dir}/gerbera-install-shell.sh
+. ${main_dir}/versions.sh
 
 VERSION="${MATROSKA-1.6.3}"
 
-script_dir=`pwd -P`
-src_dir="${script_dir}/libmatroska-${VERSION}"
-tgz_file="${script_dir}/libmatroska-${VERSION}.tar.gz"
+setFiles libmatroska tar.gz
+source_files+=("https://github.com/Matroska-Org/libmatroska/archive/refs/tags/release-${VERSION}.tar.gz")
 
 BUILD_SHARED=YES
 
@@ -36,9 +38,9 @@ if [ $# -gt 0 ]; then
     fi
 fi
 
-downloadSource https://github.com/Matroska-Org/libmatroska/archive/refs/tags/release-${VERSION}.tar.gz
+downloadSource
 
-cmake .. -DBUILD_SHARED_LIBS=${BUILD_SHARED}
+cmake .. -DBUILD_SHARED_LIBS=${BUILD_SHARED} -DCMAKE_POLICY_VERSION_MINIMUM=3.5
 
 makeInstall
 
