@@ -3,7 +3,7 @@
 #
 # install-pugixml.sh - this file is part of Gerbera.
 #
-# Copyright (C) 2018-2024 Gerbera Contributors
+# Copyright (C) 2018-2025 Gerbera Contributors
 #
 # Gerbera is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2
@@ -20,16 +20,17 @@
 # $Id$
 set -Eeuo pipefail
 
-. $(dirname "${BASH_SOURCE[0]}")/versions.sh
+main_dir=$(dirname "${BASH_SOURCE[0]}")
+main_dir=$(realpath "${main_dir}")/
+. ${main_dir}/gerbera-install-shell.sh
+. ${main_dir}/versions.sh
 
 VERSION="${PUGIXML-1.11.4}"
 
-#script_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &>/dev/null && pwd -P)
-script_dir=`pwd -P`
-src_dir="${script_dir}/pugixml-${VERSION}"
-tgz_file="${script_dir}/pugixml-${VERSION}.tgz"
+setFiles pugixml tgz
+source_files+=("https://github.com/zeux/pugixml/releases/download/v${VERSION}/pugixml-${VERSION}.tar.gz")
 
-downloadSource https://github.com/zeux/pugixml/releases/download/v${VERSION}/pugixml-${VERSION}.tar.gz
+downloadSource
 
 cmake .. -DPUGIXML_BUILD_TESTS=OFF
 
