@@ -3,7 +3,7 @@
 #
 # install-taglib.sh - this file is part of Gerbera.
 #
-# Copyright (C) 2018-2024 Gerbera Contributors
+# Copyright (C) 2018-2025 Gerbera Contributors
 #
 # Gerbera is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2
@@ -22,16 +22,15 @@ set -Eeuo pipefail
 
 main_dir=$(dirname "${BASH_SOURCE[0]}")
 main_dir=$(realpath "${main_dir}")/
+. ${main_dir}/gerbera-install-shell.sh
 . ${main_dir}/versions.sh
 
 VERSION="${TAGLIB-1.12}"
 
-script_dir=`pwd -P`
-src_dir="${script_dir}/taglib-${VERSION}"
-tgz_file="${script_dir}/taglib-${VERSION}.tgz"
-patch_file="${main_dir}/${lsb_distro}/taglib.patch"
+setFiles taglib tgz
+source_files+=("https://github.com/taglib/taglib/archive/v${VERSION}.tar.gz")
 
-downloadSource https://github.com/taglib/taglib/archive/v${VERSION}.tar.gz "-" "${patch_file}"
+downloadSource
 
 installDeps ${main_dir} taglib
 
