@@ -31,7 +31,6 @@ Gerbera - https://gerbera.io/
 
 #include "content/scripting/script_names.h"
 #include "exceptions.h"
-#include "util/logger.h"
 #include "util/tools.h"
 
 #include <algorithm>
@@ -48,7 +47,6 @@ static constexpr std::array chKeys = {
 #endif
     std::pair(ContentHandler::TRANSCODE, "Transcode"),
     std::pair(ContentHandler::EXTURL, "Exturl"),
-    std::pair(ContentHandler::MP4, "MP4"),
 #ifdef HAVE_FFMPEGTHUMBNAILER
     std::pair(ContentHandler::FFTH, "FFmpegThumbnailer"),
 #endif
@@ -60,12 +58,32 @@ static constexpr std::array chKeys = {
 #endif
 #ifdef HAVE_WAVPACK
     std::pair(ContentHandler::WAVPACK, "WavPack"),
+#endif
+#ifdef HAVE_FFMPEG
+    std::pair(ContentHandler::FFMPEG, "FFmpeg"),
 #endif
     std::pair(ContentHandler::SUBTITLE, "Subtitle"),
     std::pair(ContentHandler::METAFILE, "MetaFile"),
     std::pair(ContentHandler::RESOURCE, "Resource"),
 };
 
+static const auto otKeys = std::map<ObjectType, std::string_view> {
+    { ObjectType::Unknown, "Unknown" },
+    { ObjectType::Folder, "Folder" },
+    { ObjectType::Playlist, "Playlist" },
+    { ObjectType::Audio, "Audio" },
+    { ObjectType::Video, "Video" },
+    { ObjectType::Image, "Image" },
+#ifdef ONLINE_SERVICES
+    { ObjectType::OnlineService, "OnlineService" },
+#endif
+};
+
+std::string EnumMapper::mapObjectType(ObjectType ot)
+{
+    return otKeys.at(ot).data();
+}
+
 bool EnumMapper::checkContentHandler(const std::string& contHandler)
 {
     auto chEntry = std::find_if(chKeys.begin(), chKeys.end(), [contHandler](auto&& entry) { return contHandler == entry.second; });
