@@ -80,13 +80,13 @@ protected:
     bool virt {};
 
     /// \brief type of the object: item, container, etc.
-    unsigned int objectType {};
+    unsigned int objectType { 0 };
 
     /// \brief field which can hold various flags for the object
     unsigned int objectFlags { OBJECT_FLAG_RESTRICTED };
 
-    /// \brief flag that allows to sort objects within a container
-    int sortPriority {};
+    /// \brief property that allows to sort objects within a container
+    std::string sortKey;
 
     std::vector<std::pair<std::string, std::string>> metaData;
     std::map<std::string, std::string> auxdata;
@@ -133,10 +133,24 @@ public:
     bool isRestricted() const { return getFlag(OBJECT_FLAG_RESTRICTED); }
 
     /// \brief Set the object title (dc:title)
-    void setTitle(const std::string& title) { this->title = title; }
+    void setTitle(const std::string& title)
+    {
+        this->title = title;
+        if (this->sortKey.empty())
+            this->sortKey = title;
+    }
     /// \brief Retrieve the title.
     std::string getTitle() const { return title; }
 
+    // \brief Set the object sortKey
+    void setSortKey(const std::string& sortKey)
+    {
+        if (!sortKey.empty())
+            this->sortKey = sortKey;
+    }
+    /// \brief Retrieve the sortKey.
+    std::string getSortKey() const { return sortKey; }
+
     /// \brief set the upnp:class
     void setClass(const std::string& upnpClass) { this->upnpClass = upnpClass; }
     /// \brief Retrieve class
@@ -176,12 +190,6 @@ public:
     virtual bool isExternalItem() const { return false; }
     virtual bool isContainer() const { return false; }
 
-    /// \brief Retrieve sort priority setting.
-    int getSortPriority() const { return sortPriority; }
-
-    /// \brief Set the sort priority of an object.
-    void setSortPriority(int sortPriority) { this->sortPriority = sortPriority; }
-
     /// \brief Get flags of an object.
     unsigned int getFlags() const { return objectFlags; }
 
@@ -240,10 +248,8 @@ public:
     {
         std::map<std::string, std::vector<std::string>> metaGroups;
         for (auto&& [mkey, mvalue] : metaData) {
-            if (metaGroups.find(mkey) == metaGroups.end()) {
-                metaGroups[mkey] = {};
-            }
-            metaGroups[mkey].push_back(mvalue);
+            auto& vec = metaGroups.try_emplace(mkey).first->second;
+            vec.push_back(mvalue);
         }
         return metaGroups;
     }
@@ -360,6 +366,16 @@ public:
         return {};
     }
 
+    /// \brief Query resource attribute with the given value
+    std::shared_ptr<CdsResource> getResource(ResourceAttribute attrib, const std::string& value) const
+    {
+        auto it = std::find_if(resources.begin(), resources.end(), [=](auto&& res) { return value == res->getAttributeValue(attrib); });
+        if (it != resources.end()) {
+            return *it;
+        }
+        return {};
+    }
+
     /// \brief Add resource tag
     void addResource(const std::shared_ptr<CdsResource>& resource)
     {
