@@ -4,7 +4,7 @@
 
     config.h - this file is part of Gerbera.
 
-    Copyright (C) 2020-2024 Gerbera Contributors
+    Copyright (C) 2020-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -54,11 +54,15 @@ public:
     virtual void setOrigValue(const std::string& item, IntOptionType value) = 0;
     virtual void setOrigValue(const std::string& item, UIntOptionType value) = 0;
     virtual void setOrigValue(const std::string& item, LongOptionType value) = 0;
+    virtual void setOrigValue(const std::string& item, ULongOptionType value) = 0;
     virtual bool hasOrigValue(const std::string& item) const = 0;
 
     /// \brief Returns the path of the config file that was used to launch the server.
     virtual fs::path getConfigFilename() const = 0;
 
+    /// \brief generate UDN for server and store in database
+    virtual std::string generateUDN(const std::shared_ptr<Database>& database) = 0;
+
     /// \brief add a config option
     /// \param option option type to add.
     /// \param optionValue option to add.
@@ -75,6 +79,7 @@ public:
     virtual IntOptionType getIntOption(ConfigVal option) const = 0;
     virtual UIntOptionType getUIntOption(ConfigVal option) const = 0;
     virtual LongOptionType getLongOption(ConfigVal option) const = 0;
+    virtual ULongOptionType getULongOption(ConfigVal option) const = 0;
 
     /// \brief returns a config option of type bool
     /// \param option option to retrieve.
