@@ -76,6 +76,8 @@ public:
 
     /// \brief check whether option is only available when other option is set
     bool isDependent(ConfigVal option) const;
+    /// @brief get all options that depend on argument
+    std::vector<ConfigVal> getDependencies(ConfigVal option) const;
 
     /// \brief find setup for config option
     std::shared_ptr<ConfigSetup> findConfigSetup(ConfigVal option, bool save = false) const;
@@ -138,6 +140,7 @@ public:
         initOptions(self);
         initHierarchy();
         initDependencies();
+        markDeprecated();
     }
 
     static constexpr auto ATTRIBUTE = std::string_view("attribute::");
@@ -157,6 +160,8 @@ private:
     void initDependencies();
     /// \brief define parent options for path search
     void initHierarchy();
+    /// \brief mark option to be removed soon
+    void markDeprecated() const;
 
     /// \brief all known options
     std::vector<std::shared_ptr<ConfigSetup>> complexOptions;
