@@ -27,15 +27,12 @@
 #include "config_generator.h" // API
 
 #include "config/config_definition.h"
-#include "config/config_options.h"
 #include "config/config_setup.h"
-#include "config/result/autoscan.h"
 #include "config/result/box_layout.h"
 #include "config/setup/config_setup_boxlayout.h"
 #include "config/setup/config_setup_dictionary.h"
 #include "config/setup/config_setup_vector.h"
 #include "config_val.h"
-#include "util/grb_time.h"
 #include "util/tools.h"
 
 #include <numeric>
@@ -111,7 +108,7 @@ int ConfigGenerator::remapGeneratorSections(const std::string& arg)
     return stoiString(arg, 0, 0);
 }
 
-bool ConfigGenerator::isGenerated(GeneratorSections section)
+bool ConfigGenerator::isGenerated(GeneratorSections section) const
 {
     return this->generateSections == 0 || (this->generateSections & (1 << to_underlying(section)));
 }
@@ -122,7 +119,11 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::getNode(const std::string& tag)
     return generated.at(tag);
 }
 
-std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::string& tag, const std::shared_ptr<ConfigSetup>& cs, const std::string& value, bool makeLastChild)
+std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(
+    const std::string& tag,
+    const std::shared_ptr<ConfigSetup>& cs,
+    const std::string& value,
+    bool makeLastChild)
 {
     auto split = splitString(tag, '/');
     std::shared_ptr<pugi::xml_node> result;
@@ -168,13 +169,7 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::string& tag
     return result;
 }
 
-std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(ConfigVal option, const std::string& value)
-{
-    auto cs = definition->findConfigSetup(option);
-    return setValue(cs->xpath, cs, value.empty() ? cs->getDefaultValue() : value);
-}
-
-std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::shared_ptr<pugi::xml_node>& parent, ConfigVal option, const std::string& value)
+std::shared_ptr<pugi::xml_node> ConfigGenerator::setXmlValue(const std::shared_ptr<pugi::xml_node>& parent, ConfigVal option, const std::string& value)
 {
     auto cs = std::string(definition->mapConfigOption(option));
     if (startswith(cs, ConfigDefinition::ATTRIBUTE)) {
@@ -186,6 +181,12 @@ std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(const std::shared_ptr<
     return parent;
 }
 
+std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(ConfigVal option, const std::string& value)
+{
+    auto cs = definition->findConfigSetup(option);
+    return setValue(cs->xpath, cs, value.empty() ? cs->getDefaultValue() : value);
+}
+
 std::shared_ptr<pugi::xml_node> ConfigGenerator::setValue(ConfigVal option, ConfigVal attr, const std::string& value)
 {
     auto cs = definition->findConfigSetup(option);
@@ -255,10 +256,13 @@ std::string ConfigGenerator::generate(const fs::path& userHome, const fs::path&
     config->append_attribute("xsi:schemaLocation") = fmt::format("{}{} {}{}.xsd", XML_XMLNS, CONFIG_XML_VERSION, XML_XMLNS, CONFIG_XML_VERSION).c_str();
 
     auto docinfo = config->append_child(pugi::node_comment);
-    docinfo.set_value(R"(
+    std::string headInfo = R"(
      See https://gerbera.io or read the docs for more
      information on creating and using config.xml configuration files.
-    )");
+     This file was generated by Gerbera )";
+    headInfo += version + R"(
+  )";
+    docinfo.set_value(headInfo.c_str());
 
     generateServer(userHome, configDir, dataDir);
     generateImport(dataDir, userHome / configDir, magicFile);
@@ -302,6 +306,7 @@ void ConfigGenerator::generateServerOptions(std::shared_ptr<pugi::xml_node>& ser
         { ConfigVal::SERVER_HOME_OVERRIDE, false },
         { ConfigVal::SERVER_TMPDIR, false },
         { ConfigVal::SERVER_HIDE_PC_DIRECTORY, false },
+        { ConfigVal::SERVER_HIDE_PC_DIRECTORY_WEB, false },
         { ConfigVal::SERVER_BOOKMARK_FILE, false },
         { ConfigVal::SERVER_UPNP_TITLE_AND_DESC_STRING_LIMIT, false },
         { ConfigVal::VIRTUAL_URL, false },
@@ -385,6 +390,13 @@ void ConfigGenerator::generateUi()
         { ConfigVal::SERVER_UI_ENABLE_VIDEO, false },
         { ConfigVal::SERVER_UI_DEFAULT_ITEMS_PER_PAGE, false },
         { ConfigVal::SERVER_UI_ITEMS_PER_PAGE_DROPDOWN, false },
+        { ConfigVal::SERVER_UI_EDIT_SORTKEY, false },
+        { ConfigVal::SERVER_UI_FS_SUPPORT_ADD_ITEM, false },
+        { ConfigVal::SERVER_UI_CONTENT_SECURITY_POLICY, false },
+        { ConfigVal::SERVER_UI_EXTENSION_MIMETYPE_MAPPING, false },
+        { ConfigVal::SERVER_UI_EXTENSION_MIMETYPE_DEFAULT, false },
+        { ConfigVal::SERVER_UI_DOCUMENTATION_SOURCE, false },
+        { ConfigVal::SERVER_UI_DOCUMENTATION_USER, false },
     };
     generateOptions(options);
     setValue(ConfigVal::SERVER_UI_ACCOUNT_LIST, ConfigVal::A_SERVER_UI_ACCOUNT_LIST_ACCOUNT, ConfigVal::A_SERVER_UI_ACCOUNT_LIST_USER, DEFAULT_ACCOUNT_USER);
@@ -407,23 +419,23 @@ void ConfigGenerator::generateDynamics()
     auto&& containerTag = definition->mapConfigOption(ConfigVal::A_DYNAMIC_CONTAINER);
 
     auto container = setValue(fmt::format("{}/{}/", containersTag, containerTag), {}, "", true);
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastAdded");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Recently Added");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-last_updated");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item" and last_updated > "@last7")");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastAdded");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Recently Added");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-last_updated");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item" and last_updated > "@last7")");
 
     container = setValue(fmt::format("{}/{}/", containersTag, containerTag), {}, "", true);
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastModified");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Recently Modified");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-last_modified");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item" and last_modified > "@last7")");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastModified");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Recently Modified");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-last_modified");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item" and last_modified > "@last7")");
 
     container = setValue(fmt::format("{}/{}/", containersTag, containerTag), {}, "", true);
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastPlayed");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Music Recently Played");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-upnp:lastPlaybackTime");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_UPNP_SHORTCUT, "MUSIC_LAST_PLAYED");
-    setValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item.audioItem" and upnp:lastPlaybackTime > "@last7")");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_LOCATION, "/LastPlayed");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_TITLE, "Music Recently Played");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_SORT, "-upnp:lastPlaybackTime");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_UPNP_SHORTCUT, "MUSIC_LAST_PLAYED");
+    setXmlValue(container, ConfigVal::A_DYNAMIC_CONTAINER_FILTER, R"(upnp:class derivedfrom "object.item.audioItem" and upnp:lastPlaybackTime > "@last7")");
 }
 
 void ConfigGenerator::generateDatabase(const fs::path& prefixDir)
@@ -435,15 +447,15 @@ void ConfigGenerator::generateDatabase(const fs::path& prefixDir)
         { ConfigVal::SERVER_STORAGE_SQLITE_ENABLED, true },
         { ConfigVal::SERVER_STORAGE_SQLITE_DATABASE_FILE, true },
         { ConfigVal::SERVER_STORAGE_USE_TRANSACTIONS, false },
+        { ConfigVal::SERVER_STORAGE_SORT_KEY_ENABLED, false },
+        { ConfigVal::SERVER_STORAGE_STRING_LIMIT, false },
         { ConfigVal::SERVER_STORAGE_SQLITE_SYNCHRONOUS, false },
         { ConfigVal::SERVER_STORAGE_SQLITE_JOURNALMODE, false },
         { ConfigVal::SERVER_STORAGE_SQLITE_RESTORE, false },
         { ConfigVal::SERVER_STORAGE_SQLITE_INIT_SQL_FILE, false },
         { ConfigVal::SERVER_STORAGE_SQLITE_UPGRADE_FILE, false },
-#ifdef SQLITE_BACKUP_ENABLED
         { ConfigVal::SERVER_STORAGE_SQLITE_BACKUP_ENABLED, true },
         { ConfigVal::SERVER_STORAGE_SQLITE_BACKUP_INTERVAL, true },
-#endif
 #ifdef HAVE_MYSQL
         { ConfigVal::SERVER_STORAGE_MYSQL_ENABLED, true },
         { ConfigVal::SERVER_STORAGE_MYSQL_HOST, true },
@@ -454,6 +466,9 @@ void ConfigGenerator::generateDatabase(const fs::path& prefixDir)
         { ConfigVal::SERVER_STORAGE_MYSQL_PASSWORD, false },
         { ConfigVal::SERVER_STORAGE_MYSQL_INIT_SQL_FILE, false },
         { ConfigVal::SERVER_STORAGE_MYSQL_UPGRADE_FILE, false },
+        { ConfigVal::SERVER_STORAGE_MYSQL_ENGINE, false },
+        { ConfigVal::SERVER_STORAGE_MYSQL_CHARSET, false },
+        { ConfigVal::SERVER_STORAGE_MYSQL_COLLATION, false },
 #endif
     };
     {
@@ -528,6 +543,7 @@ void ConfigGenerator::generateImportOptions(const fs::path& prefixDir, const fs:
         { ConfigVal::IMPORT_PLAYLIST_CHARSET, false },
 #ifdef HAVE_JS
         { ConfigVal::IMPORT_SCRIPTING_CHARSET, true },
+        { ConfigVal::IMPORT_SCRIPTING_SCAN_MODE, false },
         { ConfigVal::IMPORT_SCRIPTING_COMMON_FOLDER, true },
         { ConfigVal::IMPORT_SCRIPTING_IMPORT_FUNCTION_PLAYLIST, true },
         { ConfigVal::IMPORT_SCRIPTING_IMPORT_FUNCTION_METAFILE, true },
@@ -573,6 +589,7 @@ void ConfigGenerator::generateImportOptions(const fs::path& prefixDir, const fs:
         { ConfigVal::IMPORT_LIBOPTS_FFMPEG_ENABLED, false },
         { ConfigVal::IMPORT_LIBOPTS_FFMPEG_COMMENT_LIST, false },
         { ConfigVal::IMPORT_LIBOPTS_FFMPEG_COMMENT_ENABLED, false },
+        { ConfigVal::IMPORT_LIBOPTS_FFMPEG_ARTWORK_ENABLED, false },
 #endif
 #ifdef HAVE_MATROSKA
         { ConfigVal::IMPORT_LIBOPTS_MKV_AUXDATA_TAGS_LIST, false },
@@ -648,18 +665,18 @@ void ConfigGenerator::generateImportOptions(const fs::path& prefixDir, const fs:
 #ifdef HAVE_INOTIFY
         auto&& autoscanTag = definition->mapConfigOption(ConfigVal::IMPORT_AUTOSCAN_INOTIFY_LIST);
         auto as = setValue(fmt::format("{}/{}/", autoscanTag, directoryTag), {}, "", true);
-        setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_LOCATION, "/media");
-        setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_MODE, "inotify");
+        setXmlValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_LOCATION, "/media");
+        setXmlValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_MODE, "inotify");
 #else
         auto&& autoscanTag = definition->mapConfigOption(ConfigVal::IMPORT_AUTOSCAN_TIMED_LIST);
         auto as = setValue(fmt::format("{}/{}/", autoscanTag, directoryTag), {}, "", true);
-        setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_LOCATION, "/media");
-        setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_MODE, "timed");
-        setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_INTERVAL, "1000");
+        setXmlValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_LOCATION, "/media");
+        setXmlValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_MODE, "timed");
+        setXmlValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_INTERVAL, "1000");
 #endif
-        setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_RECURSIVE, "yes");
-        setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_HIDDENFILES, "yes");
-        setValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_MEDIATYPE, "Any");
+        setXmlValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_RECURSIVE, "yes");
+        setXmlValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_HIDDENFILES, "yes");
+        setXmlValue(as, ConfigVal::A_AUTOSCAN_DIRECTORY_MEDIATYPE, "Any");
     }
     {
         // Generate Charsets
@@ -703,7 +720,7 @@ void ConfigGenerator::generateImport(const fs::path& prefixDir, const fs::path&
 {
     generateImportOptions(prefixDir, configDir, magicFile);
     generateMappings();
-    generateBoxlayout(ConfigVal::BOXLAYOUT_BOX);
+    generateBoxlayout(ConfigVal::BOXLAYOUT_LIST);
 #ifdef ONLINE_SERVICES
     generateOnlineContent();
 #endif
@@ -742,19 +759,22 @@ void ConfigGenerator::generateBoxlayout(ConfigVal option)
 
     auto cs = definition->findConfigSetup<ConfigBoxLayoutSetup>(option);
 
-    const auto boxTag = definition->mapConfigOption(option);
+    const auto boxListTag = definition->mapConfigOption(option);
+    const auto boxTag = definition->mapConfigOption(ConfigVal::A_BOXLAYOUT_BOX);
 
     for (auto&& bl : cs->getDefault()) {
-        auto box = setValue(fmt::format("{}/", boxTag), {}, "", true);
-        setValue(box, ConfigVal::A_BOXLAYOUT_BOX_KEY, bl.getKey());
-        setValue(box, ConfigVal::A_BOXLAYOUT_BOX_TITLE, bl.getTitle());
-        setValue(box, ConfigVal::A_BOXLAYOUT_BOX_CLASS, bl.getClass());
+        auto box = setValue(fmt::format("{}/{}/", boxListTag, boxTag), {}, "", true);
+        setXmlValue(box, ConfigVal::A_BOXLAYOUT_BOX_KEY, bl.getKey());
+        setXmlValue(box, ConfigVal::A_BOXLAYOUT_BOX_TITLE, bl.getTitle());
+        setXmlValue(box, ConfigVal::A_BOXLAYOUT_BOX_CLASS, bl.getClass());
         if (!bl.getUpnpShortcut().empty())
-            setValue(box, ConfigVal::A_BOXLAYOUT_BOX_UPNP_SHORTCUT, bl.getUpnpShortcut());
+            setXmlValue(box, ConfigVal::A_BOXLAYOUT_BOX_UPNP_SHORTCUT, bl.getUpnpShortcut());
+        if (!bl.getSortKey().empty())
+            setXmlValue(box, ConfigVal::A_BOXLAYOUT_BOX_SORT_KEY, bl.getSortKey());
         if (bl.getSize() != 1)
-            setValue(box, ConfigVal::A_BOXLAYOUT_BOX_SIZE, fmt::to_string(bl.getSize()));
+            setXmlValue(box, ConfigVal::A_BOXLAYOUT_BOX_SIZE, fmt::to_string(bl.getSize()));
         if (!bl.getEnabled())
-            setValue(box, ConfigVal::A_BOXLAYOUT_BOX_ENABLED, fmt::to_string(bl.getEnabled()));
+            setXmlValue(box, ConfigVal::A_BOXLAYOUT_BOX_ENABLED, fmt::to_string(bl.getEnabled()));
     }
 }
 
@@ -791,40 +811,52 @@ void ConfigGenerator::generateTranscoding()
     const auto profileTag = definition->mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE);
 
     auto oggmp3 = setValue(fmt::format("{}/", profileTag), {}, "", true);
-    setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_NAME, "ogg2mp3");
-    setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ENABLED, NO);
-    setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_TYPE, "external");
-    setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_MIMETYPE, "audio/mpeg");
-    setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCURL, NO);
-    setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_FIRST, YES);
-    setValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCOGG, NO);
+    setXmlValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_NAME, "ogg2mp3");
+    setXmlValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ENABLED, NO);
+    setXmlValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_TYPE, "external");
+    setXmlValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_MIMETYPE, "audio/mpeg");
+    setXmlValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCURL, NO);
+    setXmlValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_FIRST, YES);
+    setXmlValue(oggmp3, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCOGG, NO);
 
     auto agent = setValue(fmt::format("{}/{}/", profileTag, definition->mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT)), {}, "", true);
-    setValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND, "ffmpeg");
-    setValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS, "-y -i %in -f mp3 %out");
+    setXmlValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND, "ffmpeg");
+    setXmlValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS, "-y -i %in -f mp3 %out");
 
     auto buffer = setValue(fmt::format("{}/{}/", profileTag, definition->mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER)), {}, "", true);
-    setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_SIZE, fmt::to_string(DEFAULT_AUDIO_BUFFER_SIZE));
-    setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_CHUNK, fmt::to_string(DEFAULT_AUDIO_CHUNK_SIZE));
-    setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_FILL, fmt::to_string(DEFAULT_AUDIO_FILL_SIZE));
+    setXmlValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_SIZE, fmt::to_string(DEFAULT_AUDIO_BUFFER_SIZE));
+    setXmlValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_CHUNK, fmt::to_string(DEFAULT_AUDIO_CHUNK_SIZE));
+    setXmlValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_FILL, fmt::to_string(DEFAULT_AUDIO_FILL_SIZE));
 
     auto vlcmpeg = setValue(fmt::format("{}/", profileTag), {}, "", true);
-    setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_NAME, "vlcmpeg");
-    setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ENABLED, NO);
-    setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_TYPE, "external");
-    setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_MIMETYPE, "video/mpeg");
-    setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCURL, YES);
-    setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_FIRST, YES);
-    setValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCOGG, YES);
+    setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_NAME, "vlcmpeg");
+    setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ENABLED, NO);
+    setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_TYPE, "external");
+    setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_MIMETYPE, "video/mpeg");
+    setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCURL, YES);
+    setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_FIRST, YES);
+    setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_ACCOGG, YES);
+    if (example) {
+        setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_SAMPFREQ, GRB_STRINGIZE(SOURCE));
+        setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_NRCHAN, GRB_STRINGIZE(SOURCE));
+        setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_THUMB, NO);
+        setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_HIDEORIG, NO);
+        setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_NOTRANSCODING, "");
+        setXmlValue(vlcmpeg, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_DLNAPROF, "MP4");
+        auto fourCc = setValue(fmt::format("{}/{}/", profileTag, definition->mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AVI4CC)), {}, "", true);
+        setXmlValue(fourCc, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AVI4CC_MODE, "Ignore");
+        setXmlValue(fourCc, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC, "XVID");
+        setXmlValue(fourCc, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC, "DX50");
+    }
 
     agent = setValue(fmt::format("{}/{}/", profileTag, definition->mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT)), {}, "", true);
-    setValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND, "vlc");
-    setValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS, "-I dummy %in --sout #transcode{venc=ffmpeg,vcodec=mp2v,vb=4096,fps=25,aenc=ffmpeg,acodec=mpga,ab=192,samplerate=44100,channels=2}:standard{access=file,mux=ps,dst=%out} vlc://quit");
+    setXmlValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_COMMAND, "vlc");
+    setXmlValue(agent, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_AGENT_ARGS, "-I dummy %in --sout #transcode{venc=ffmpeg,vcodec=mp2v,vb=4096,fps=25,aenc=ffmpeg,acodec=mpga,ab=192,samplerate=44100,channels=2}:standard{access=file,mux=ps,dst=%out} vlc://quit");
 
     buffer = setValue(fmt::format("{}/{}/", profileTag, definition->mapConfigOption(ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER)), {}, "", true);
-    setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_SIZE, fmt::to_string(DEFAULT_VIDEO_BUFFER_SIZE));
-    setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_CHUNK, fmt::to_string(DEFAULT_VIDEO_CHUNK_SIZE));
-    setValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_FILL, fmt::to_string(DEFAULT_VIDEO_FILL_SIZE));
+    setXmlValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_SIZE, fmt::to_string(DEFAULT_VIDEO_BUFFER_SIZE));
+    setXmlValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_CHUNK, fmt::to_string(DEFAULT_VIDEO_CHUNK_SIZE));
+    setXmlValue(buffer, ConfigVal::A_TRANSCODING_PROFILES_PROFLE_BUFFER_FILL, fmt::to_string(DEFAULT_VIDEO_FILL_SIZE));
 }
 
 void ConfigGenerator::generateUdn(bool doExport)
