@@ -176,12 +176,8 @@ void ConfigManager::load(const fs::path& userHome)
 #ifdef HAVE_MYSQL
     if (mysqlEn) {
         // read mysql options
-        setOption(root, ConfigVal::SERVER_STORAGE_MYSQL_HOST);
-        setOption(root, ConfigVal::SERVER_STORAGE_MYSQL_DATABASE);
-        setOption(root, ConfigVal::SERVER_STORAGE_MYSQL_USERNAME);
-        setOption(root, ConfigVal::SERVER_STORAGE_MYSQL_PORT);
-        setOption(root, ConfigVal::SERVER_STORAGE_MYSQL_SOCKET);
-        setOption(root, ConfigVal::SERVER_STORAGE_MYSQL_PASSWORD);
+        for (auto&& option : definition->getDependencies(ConfigVal::SERVER_STORAGE_MYSQL_ENABLED))
+            setOption(root, option);
 
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_MYSQL_INIT_SQL_FILE);
         co->setDefaultValue(dataDir / "mysql.sql");
@@ -195,12 +191,8 @@ void ConfigManager::load(const fs::path& userHome)
 
     if (sqlite3En) {
         // read sqlite options
-        setOption(root, ConfigVal::SERVER_STORAGE_SQLITE_DATABASE_FILE);
-        setOption(root, ConfigVal::SERVER_STORAGE_SQLITE_SYNCHRONOUS);
-        setOption(root, ConfigVal::SERVER_STORAGE_SQLITE_JOURNALMODE);
-        setOption(root, ConfigVal::SERVER_STORAGE_SQLITE_RESTORE);
-        setOption(root, ConfigVal::SERVER_STORAGE_SQLITE_BACKUP_ENABLED);
-        setOption(root, ConfigVal::SERVER_STORAGE_SQLITE_BACKUP_INTERVAL);
+        for (auto&& option : definition->getDependencies(ConfigVal::SERVER_STORAGE_SQLITE_ENABLED))
+            setOption(root, option);
 
         co = definition->findConfigSetup(ConfigVal::SERVER_STORAGE_SQLITE_INIT_SQL_FILE);
         co->setDefaultValue(dataDir / "sqlite3.sql");
@@ -289,8 +281,9 @@ void ConfigManager::load(const fs::path& userHome)
 
 #ifdef HAVE_CURL
     if (trEn) {
-        setOption(root, ConfigVal::EXTERNAL_TRANSCODING_CURL_BUFFER_SIZE);
-        setOption(root, ConfigVal::EXTERNAL_TRANSCODING_CURL_FILL_SIZE);
+        for (auto&& option : definition->getDependencies(ConfigVal::TRANSCODING_TRANSCODING_ENABLED)) {
+            setOption(root, option);
+        }
     }
 #endif // HAVE_CURL
 
@@ -304,20 +297,18 @@ void ConfigManager::load(const fs::path& userHome)
 #ifdef HAVE_FFMPEGTHUMBNAILER
     auto ffmpEn = setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED)->getBoolOption();
     if (ffmpEn) {
-        setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_THUMBSIZE);
-        setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_SEEK_PERCENTAGE);
-        setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_FILMSTRIP_OVERLAY);
-        setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_IMAGE_QUALITY);
-        setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR_ENABLED);
-        setOption(root, ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_CACHE_DIR);
+        for (auto&& option : definition->getDependencies(ConfigVal::SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED)) {
+            setOption(root, option);
+        }
     }
 #endif
 
 #ifdef HAVE_LASTFMLIB
     auto lfmEn = setOption(root, ConfigVal::SERVER_EXTOPTS_LASTFM_ENABLED)->getBoolOption();
     if (lfmEn) {
-        setOption(root, ConfigVal::SERVER_EXTOPTS_LASTFM_USERNAME);
-        setOption(root, ConfigVal::SERVER_EXTOPTS_LASTFM_PASSWORD);
+        for (auto&& option : definition->getDependencies(ConfigVal::SERVER_EXTOPTS_LASTFM_ENABLED)) {
+            setOption(root, option);
+        }
     }
 #endif
 
@@ -411,10 +402,20 @@ bool ConfigManager::validate()
                                 "however you specified \"js\" to be used for the "
                                 "virtual-layout.");
 #endif
-    auto co = definition->findConfigSetup<ConfigBoxLayoutSetup>(ConfigVal::BOXLAYOUT_BOX);
-    if (!co->validate(getSelf(), getBoxLayoutListOption(ConfigVal::BOXLAYOUT_BOX)))
+    auto co = definition->findConfigSetup<ConfigBoxLayoutSetup>(ConfigVal::BOXLAYOUT_LIST);
+    if (!co->validate(getSelf(), getBoxLayoutListOption(ConfigVal::BOXLAYOUT_LIST)))
         throw_std_runtime_error("Validation of {} failed", co->xpath);
 
+    auto helpRoot = getOption(ConfigVal::SERVER_UI_DOCUMENTATION_USER);
+    for (auto&& optionKey : ConfigOptionIterator()) {
+        if (options.at(to_underlying(optionKey))) {
+            auto cs = definition->findConfigSetup(optionKey);
+            if (cs->isOptionDeprecated() && !cs->isDefaultValueUsed()) {
+                log_warning("Option {} is deprecated, see {}/{} and update your config.xml ", cs->xpath, helpRoot, cs->getHelp());
+            }
+        }
+    }
+
     log_info("Configuration check succeeded.");
     return true;
 }
@@ -495,6 +496,11 @@ void ConfigManager::setOrigValue(const std::string& item, LongOptionType value)
     origValues.try_emplace(item, fmt::to_string(value));
 }
 
+void ConfigManager::setOrigValue(const std::string& item, ULongOptionType value)
+{
+    origValues.try_emplace(item, fmt::to_string(value));
+}
+
 // The validate function ensures that the array is completely filled!
 std::string ConfigManager::getOption(ConfigVal option) const
 {
@@ -560,6 +566,22 @@ LongOptionType ConfigManager::getLongOption(ConfigVal option) const
     }
 }
 
+ULongOptionType ConfigManager::getULongOption(ConfigVal option) const
+{
+    try {
+        auto optionValue = options.at(to_underlying(option));
+        if (!optionValue) {
+            auto cs = definition->findConfigSetup(option);
+            throw_std_runtime_error("long option {}='{}' not set", option, cs->getItemPathRoot());
+        }
+        return optionValue->getULongOption();
+    } catch (const std::out_of_range& oor) {
+        log_error("{}", oor.what());
+        auto cs = definition->findConfigSetup(option);
+        throw_std_runtime_error("unset long option {}='{}'", option, cs->getItemPathRoot());
+    }
+}
+
 std::shared_ptr<ConfigOption> ConfigManager::getConfigOption(ConfigVal option) const
 {
     try {
