@@ -50,6 +50,7 @@ enum class ConfigVal {
     SERVER_WEBROOT,
     SERVER_ALIVE_INTERVAL,
     SERVER_HIDE_PC_DIRECTORY,
+    SERVER_HIDE_PC_DIRECTORY_WEB,
     SERVER_BOOKMARK_FILE,
     SERVER_UPNP_TITLE_AND_DESC_STRING_LIMIT,
     SERVER_UI_ENABLED,
@@ -65,6 +66,7 @@ enum class ConfigVal {
     SERVER_UI_ITEMS_PER_PAGE_DROPDOWN,
     SERVER_UI_SHOW_TOOLTIPS,
     SERVER_UI_FS_SUPPORT_ADD_ITEM,
+    SERVER_UI_EDIT_SORTKEY,
     SERVER_UI_CONTENT_SECURITY_POLICY,
     SERVER_UI_EXTENSION_MIMETYPE_MAPPING,
     SERVER_UI_EXTENSION_MIMETYPE_DEFAULT,
@@ -75,6 +77,8 @@ enum class ConfigVal {
     SERVER_STORAGE_SQLITE,
     SERVER_STORAGE_DRIVER,
     SERVER_STORAGE_USE_TRANSACTIONS,
+    SERVER_STORAGE_SORT_KEY_ENABLED,
+    SERVER_STORAGE_STRING_LIMIT,
     SERVER_STORAGE_SQLITE_ENABLED,
     SERVER_STORAGE_SQLITE_DATABASE_FILE,
     SERVER_STORAGE_SQLITE_SYNCHRONOUS,
@@ -95,6 +99,9 @@ enum class ConfigVal {
     SERVER_STORAGE_MYSQL_DATABASE,
     SERVER_STORAGE_MYSQL_INIT_SQL_FILE,
     SERVER_STORAGE_MYSQL_UPGRADE_FILE,
+    SERVER_STORAGE_MYSQL_ENGINE,
+    SERVER_STORAGE_MYSQL_CHARSET,
+    SERVER_STORAGE_MYSQL_COLLATION,
 #endif
 #ifdef HAVE_FFMPEGTHUMBNAILER
     SERVER_EXTOPTS_FFMPEGTHUMBNAILER_ENABLED,
@@ -131,6 +138,8 @@ enum class ConfigVal {
     IMPORT_PLAYLIST_CHARSET,
 #ifdef HAVE_JS
     IMPORT_SCRIPTING_CHARSET,
+    IMPORT_SCRIPTING_SCAN_MODE,
+    IMPORT_SCRIPTING_SCAN_INTERVAL,
     IMPORT_SCRIPTING_COMMON_SCRIPT,
     IMPORT_SCRIPTING_CUSTOM_SCRIPT,
     IMPORT_SCRIPTING_METAFILE_SCRIPT,
@@ -218,6 +227,7 @@ enum class ConfigVal {
     IMPORT_LIBOPTS_FFMPEG_ENABLED,
     IMPORT_LIBOPTS_FFMPEG_COMMENT_ENABLED,
     IMPORT_LIBOPTS_FFMPEG_COMMENT_LIST,
+    IMPORT_LIBOPTS_FFMPEG_ARTWORK_ENABLED,
 #endif
 #ifdef HAVE_MATROSKA
     IMPORT_LIBOPTS_MKV_AUXDATA_TAGS_LIST,
@@ -239,7 +249,7 @@ enum class ConfigVal {
     CLIENTS_LIST_ENABLED,
     CLIENTS_CACHE_THRESHOLD,
     CLIENTS_BOOKMARK_OFFSET,
-    BOXLAYOUT_BOX,
+    BOXLAYOUT_LIST,
     IMPORT_LAYOUT_PARENT_PATH,
     IMPORT_LAYOUT_MAPPING,
     IMPORT_LIBOPTS_ENTRY_SEP,
@@ -323,6 +333,7 @@ enum class ConfigVal {
     A_IMPORT_RESOURCES_NAME,
     A_IMPORT_RESOURCES_PTT,
     A_IMPORT_RESOURCES_EXT,
+    A_IMPORT_RESOURCES_MIME,
     A_IMPORT_VIRT_DIR_KEY,
     A_IMPORT_VIRT_DIR_METADATA,
     A_IMPORT_LIBOPTS_AUXDATA_DATA,
@@ -404,10 +415,16 @@ enum class ConfigVal {
     A_CLIENTS_GROUP_HIDDEN_LIST,
     A_CLIENTS_GROUP_HIDE,
     A_CLIENTS_GROUP_LOCATION,
+    A_BOXLAYOUT_BOX,
+    A_BOXLAYOUT_CHAIN,
+    A_BOXLAYOUT_CHAIN_LINKS,
+    A_BOXLAYOUT_CHAIN_LINK,
+    A_BOXLAYOUT_CHAIN_TYPE,
     A_BOXLAYOUT_BOX_KEY,
     A_BOXLAYOUT_BOX_TITLE,
     A_BOXLAYOUT_BOX_CLASS,
     A_BOXLAYOUT_BOX_UPNP_SHORTCUT,
+    A_BOXLAYOUT_BOX_SORT_KEY,
     A_BOXLAYOUT_BOX_SIZE,
     A_BOXLAYOUT_BOX_ENABLED,
     A_DIRECTORIES_TWEAK,
