@@ -23,7 +23,6 @@ Gerbera - https://gerbera.io/
 
 #include "grb_runtime.h" // API
 
-#include "common.h"
 #include "config/config.h"
 #include "config/config_definition.h"
 #include "config/config_generator.h"
@@ -183,7 +182,7 @@ bool GerberaRuntime::setLogFile(const std::string& arg)
         defaultLogger = spdlog::default_logger();
     spdlog::set_default_logger(fileLogger);
     spdlog::flush_on(spdlog::level::trace);
-    grbLoggers.push_back("file_logger");
+    grbLoggers.emplace_back("file_logger");
     return true;
 }
 
@@ -200,7 +199,7 @@ bool GerberaRuntime::setRotatelog(const std::string& arg)
         defaultLogger = spdlog::default_logger();
     spdlog::set_default_logger(rotateLogger);
     spdlog::flush_on(spdlog::level::trace);
-    grbLoggers.push_back("rotate_logger");
+    grbLoggers.emplace_back("rotate_logger");
     return true;
 }
 
@@ -216,7 +215,7 @@ bool GerberaRuntime::setSyslog(const std::string& arg)
         defaultLogger = spdlog::default_logger();
     spdlog::set_default_logger(sysLogger);
     spdlog::flush_on(spdlog::level::trace);
-    grbLoggers.push_back("syslog_logger");
+    grbLoggers.emplace_back("syslog_logger");
     return true;
 }
 
@@ -487,7 +486,7 @@ bool GerberaRuntime::checkDirs()
 
 bool GerberaRuntime::printConfig()
 {
-    ConfigGenerator configGenerator(definition, exampleConfigSet, sections);
+    ConfigGenerator configGenerator(definition, GERBERA_VERSION, exampleConfigSet, sections);
     if (!configDirSet) {
         confDir = "";
     }
