@@ -117,9 +117,9 @@ public:
         bool followSymlinks = false,
         int mediaType = -1,
         const std::map<AutoscanMediaMode, std::string>& containerMap = ContainerTypesDefaults);
-    virtual ~AutoscanDirectory() = default;
+    ~AutoscanDirectory() override = default;
 
-    bool equals(const std::shared_ptr<AutoscanDirectory>& other) { return this->getScanID() == other->getScanID(); }
+    bool equals(const std::shared_ptr<AutoscanDirectory>& other) const { return this->getScanID() == other->getScanID(); }
 
     void setDatabaseID(int databaseID) { this->databaseID = databaseID; }
     int getDatabaseID() const { return databaseID; }
