@@ -73,11 +73,10 @@
 
 #ifdef HAVE_INOTIFY
 #include "content/inotify/autoscan_inotify.h"
+#include "content/inotify/scripting_inotify.h"
 #endif
 
 #include <algorithm>
-#include <fmt/chrono.h>
-#include <regex>
 
 ContentManager::ContentManager(const std::shared_ptr<Context>& context,
     const std::shared_ptr<Server>& server, std::shared_ptr<Timer> timer)
@@ -101,6 +100,12 @@ ContentManager::ContentManager(const std::shared_ptr<Context>& context,
 #endif
     importService = std::make_shared<ImportService>(this->context, converterManager);
     importMode = EnumOption<ImportMode>::getEnumOption(config, ConfigVal::IMPORT_LAYOUT_MODE);
+#ifdef HAVE_INOTIFY
+    useAsInotify = config->getBoolOption(ConfigVal::IMPORT_AUTOSCAN_USE_INOTIFY);
+#endif
+#ifdef HAVE_JS
+    scriptScanMode = EnumOption<AutoscanScanMode>::getEnumOption(config, ConfigVal::IMPORT_SCRIPTING_SCAN_MODE);
+#endif
 }
 
 void ContentManager::run()
@@ -136,8 +141,12 @@ void ContentManager::run()
     auto cfScans = std::vector<ConfigVal> { ConfigVal::IMPORT_AUTOSCAN_TIMED_LIST, ConfigVal::IMPORT_AUTOSCAN_MANUAL_LIST };
 
 #ifdef HAVE_INOTIFY
-    inotify = std::make_unique<AutoscanInotify>(self);
-    if (config->getBoolOption(ConfigVal::IMPORT_AUTOSCAN_USE_INOTIFY)) {
+    as_inotify = std::make_unique<AutoscanInotify>(self);
+#ifdef HAVE_JS
+    if (scriptScanMode == AutoscanScanMode::INotify)
+        script_inotify = std::make_unique<ScriptingInotify>(config, scriptingRuntime);
+#endif
+    if (useAsInotify) {
         dbScans.push_back(AutoscanScanMode::INotify);
         cfScans.push_back(ConfigVal::IMPORT_AUTOSCAN_INOTIFY_LIST);
     }
@@ -186,7 +195,7 @@ void ContentManager::run()
     }
 #ifdef HAVE_INOTIFY
     // Start INotify thread
-    inotify->run();
+    as_inotify->run();
 #endif
 
     auto layoutType = EnumOption<LayoutType>::getEnumOption(config, ConfigVal::IMPORT_SCRIPTING_VIRTUAL_LAYOUT_TYPE);
@@ -203,10 +212,29 @@ void ContentManager::run()
     autoscanList->notifyAll(this);
     auto self_content = std::dynamic_pointer_cast<Content>(self);
 #ifdef HAVE_INOTIFY
-    autoscanList->initTimer(self_content, timer, config->getBoolOption(ConfigVal::IMPORT_AUTOSCAN_USE_INOTIFY), inotify);
+    autoscanList->initTimer(self_content, timer, useAsInotify, as_inotify);
+#ifdef HAVE_JS
+    if (scriptScanMode == AutoscanScanMode::INotify) {
+        log_info("Adding inotify script scan");
+        script_inotify->run();
+        std::string customFolderPath = config->getOption(ConfigVal::IMPORT_SCRIPTING_CUSTOM_FOLDER);
+        std::string commonFolderPath = config->getOption(ConfigVal::IMPORT_SCRIPTING_COMMON_FOLDER);
+        if (!customFolderPath.empty())
+            script_inotify->monitor(customFolderPath);
+        if (!commonFolderPath.empty())
+            script_inotify->monitor(commonFolderPath);
+    }
+#endif
 #else
     autoscanList->initTimer(self_content, timer);
 #endif
+#ifdef HAVE_JS
+    if (scriptScanMode == AutoscanScanMode::Timed) {
+        auto param = std::make_shared<Timer::Parameter>(Timer::TimerParamType::IDScript, 0);
+        log_info("Adding timed script scan with interval {} minutes", config->getLongOption(ConfigVal::IMPORT_SCRIPTING_SCAN_INTERVAL));
+        timer->addTimerSubscriber(this, std::chrono::minutes(config->getLongOption(ConfigVal::IMPORT_SCRIPTING_SCAN_INTERVAL)), std::move(param), false);
+    }
+#endif
 }
 
 void ContentManager::registerExecutor(const std::shared_ptr<Executor>& exec)
@@ -245,11 +273,16 @@ void ContentManager::timerNotify(const std::shared_ptr<Timer::Parameter>& parame
 
         rescanDirectory(adir, adir->getObjectID());
     }
+#ifdef HAVE_JS
+    else if (parameter->whoami() == Timer::TimerParamType::IDScript) {
+        scriptingRuntime->reloadFolders();
+    }
+#endif
 #ifdef ONLINE_SERVICES
     else if (parameter->whoami() == Timer::TimerParamType::IDOnlineContent) {
         fetchOnlineContent(static_cast<OnlineServiceType>(parameter->getID()));
     }
-#endif // ONLINE_SERVICES
+#endif
 }
 
 void ContentManager::shutdown()
@@ -278,7 +311,11 @@ void ContentManager::shutdown()
 
         autoscanList.reset();
 #ifdef HAVE_INOTIFY
-        inotify.reset();
+        as_inotify.reset();
+#ifdef HAVE_JS
+        if (scriptScanMode == AutoscanScanMode::INotify)
+            script_inotify.reset();
+#endif
 #endif
     }
 
@@ -409,6 +446,7 @@ std::shared_ptr<CdsObject> ContentManager::createSingleItem(
     } else if (obj->isItem() && processExisting) {
         auto item = std::static_pointer_cast<CdsItem>(obj);
         getImportService(adir)->getMetadataService()->extractMetaData(item, dirEnt);
+        getImportService(adir)->getMetadataService()->attachResourceFiles(item, dirEnt);
         getImportService(adir)->updateItemData(item, item->getMimeType());
     }
     if (processExisting || isNew) {
@@ -442,11 +480,10 @@ std::shared_ptr<CdsObject> ContentManager::_addFile(
 
     if (importMode == ImportMode::Gerbera) {
         std::unordered_set<int> currentContent;
-        if (asSetting.changedObject)
+        if (asSetting.changedObject || !asSetting.adir || asSetting.adir->getScanMode() != AutoscanScanMode::INotify) {
             importService->clearCache(); // may be called by layout
-        getImportService(asSetting.adir)->doImport(dirEnt.path(), asSetting, currentContent, task);
-
-        return getImportService(asSetting.adir)->getObject(dirEnt.path());
+        }
+        return getImportService(asSetting.adir)->doImport(dirEnt.path(), asSetting, currentContent, task);
     }
     // checkDatabase, don't process existing
     std::shared_ptr<CdsContainer> parent;
@@ -674,8 +711,9 @@ void ContentManager::_rescanDirectory(const std::shared_ptr<AutoscanDirectory>&
     }
 
     if (importMode == ImportMode::Gerbera) {
-        if (asSetting.changedObject)
+        if (asSetting.changedObject || !adir || adir->getScanMode() != AutoscanScanMode::INotify) {
             importService->clearCache(); // may be called by layout
+        }
         getImportService(adir)->doImport(location, asSetting, list, task);
     } else {
         auto lastModifiedCurrentMax = adir->getPreviousLMT(location, parentContainer);
@@ -848,7 +886,7 @@ std::shared_ptr<AutoscanDirectory> ContentManager::findAutoscanDirectory(fs::pat
         if (dir) {
             log_debug("AutoscanDir ({}): {}", AutoscanDirectory::mapScanmode(dir->getScanMode()), i);
             if (isSubDir(path, dir->getLocation()) && fs::is_directory(dir->getLocation(), ec)) {
-                autoscanDir = std::move(dir);
+                autoscanDir = dir;
             }
             if (ec) {
                 log_warning("No AutoscanDir {} has problems '{}'", dir->getLocation().string(), ec.message());
@@ -972,6 +1010,7 @@ template <typename T>
 std::shared_ptr<CdsObject> ContentManager::updateCdsObject(const std::shared_ptr<T>& item, const std::map<std::string, std::string>& parameters)
 {
     std::string title = getValueOrDefault(parameters, "title");
+    std::string sortKey = getValueOrDefault(parameters, "sortKey");
     std::string upnpClass = getValueOrDefault(parameters, "class");
     std::string mimetype = getValueOrDefault(parameters, "mime-type");
     std::string description = getValueOrDefault(parameters, "description");
@@ -987,6 +1026,7 @@ template <>
 std::shared_ptr<CdsObject> ContentManager::updateCdsObject(const std::shared_ptr<CdsContainer>& item, const std::map<std::string, std::string>& parameters)
 {
     std::string title = getValueOrDefault(parameters, "title");
+    std::string sortKey = getValueOrDefault(parameters, "sortKey");
     std::string upnpClass = getValueOrDefault(parameters, "class");
     std::string flags = getValueOrDefault(parameters, "flags");
 
@@ -997,6 +1037,8 @@ std::shared_ptr<CdsObject> ContentManager::updateCdsObject(const std::shared_ptr
 
     if (!title.empty())
         clone->setTitle(title);
+    if (!sortKey.empty())
+        clone->setSortKey(sortKey);
     if (!upnpClass.empty())
         clone->setClass(upnpClass);
     if (!flags.empty())
@@ -1026,6 +1068,7 @@ std::shared_ptr<CdsObject> ContentManager::updateCdsObject(const std::shared_ptr
     std::string mimetype = getValueOrDefault(parameters, "mime-type");
     std::string description = getValueOrDefault(parameters, "description");
     std::string location = getValueOrDefault(parameters, "location");
+    std::string sortKey = getValueOrDefault(parameters, "sortKey");
     std::string protocol = getValueOrDefault(parameters, "protocol");
     std::string flags = getValueOrDefault(parameters, "flags");
     log_debug("updateCdsObject: CdsItem {} updated", title);
@@ -1035,6 +1078,8 @@ std::shared_ptr<CdsObject> ContentManager::updateCdsObject(const std::shared_ptr
 
     if (!title.empty())
         clone->setTitle(title);
+    if (!sortKey.empty())
+        clone->setSortKey(sortKey);
     if (!upnpClass.empty())
         clone->setClass(upnpClass);
     if (!location.empty())
@@ -1473,8 +1518,8 @@ void ContentManager::cleanupTasks(const fs::path& path)
         if (dir->getScanMode() == AutoscanScanMode::Timed) {
             timer->removeTimerSubscriber(this, rmList->get(i)->getTimerParameter(), true);
 #ifdef HAVE_INOTIFY
-        } else if (config->getBoolOption(ConfigVal::IMPORT_AUTOSCAN_USE_INOTIFY)) {
-            inotify->unmonitor(dir);
+        } else if (useAsInotify) {
+            as_inotify->unmonitor(dir);
 #endif
         }
     }
@@ -1551,8 +1596,8 @@ void ContentManager::removeAutoscanDirectory(const std::shared_ptr<AutoscanDirec
         timer->removeTimerSubscriber(this, adir->getTimerParameter(), true);
     }
 #ifdef HAVE_INOTIFY
-    else if (config->getBoolOption(ConfigVal::IMPORT_AUTOSCAN_USE_INOTIFY) && (adir->getScanMode() == AutoscanScanMode::INotify)) {
-        inotify->unmonitor(adir);
+    else if (useAsInotify && (adir->getScanMode() == AutoscanScanMode::INotify)) {
+        as_inotify->unmonitor(adir);
     }
 #endif
 }
@@ -1616,8 +1661,8 @@ void ContentManager::setAutoscanDirectory(const std::shared_ptr<AutoscanDirector
     if (original->getScanMode() == AutoscanScanMode::Timed)
         timer->removeTimerSubscriber(this, original->getTimerParameter(), true);
 #ifdef HAVE_INOTIFY
-    else if (config->getBoolOption(ConfigVal::IMPORT_AUTOSCAN_USE_INOTIFY) && (original->getScanMode() == AutoscanScanMode::INotify))
-        inotify->unmonitor(original);
+    else if (useAsInotify && (original->getScanMode() == AutoscanScanMode::INotify))
+        as_inotify->unmonitor(original);
 #endif
 
     auto copy = std::make_shared<AutoscanDirectory>();
@@ -1647,8 +1692,8 @@ void ContentManager::scanDir(const std::shared_ptr<AutoscanDirectory>& dir, bool
     if (dir->getScanMode() == AutoscanScanMode::Timed)
         timerNotify(dir->getTimerParameter());
 #ifdef HAVE_INOTIFY
-    else if (config->getBoolOption(ConfigVal::IMPORT_AUTOSCAN_USE_INOTIFY) && (dir->getScanMode() == AutoscanScanMode::INotify))
-        inotify->monitor(dir);
+    else if (useAsInotify && (dir->getScanMode() == AutoscanScanMode::INotify))
+        as_inotify->monitor(dir);
 #endif
 
     if (updateUI)
