@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,7 +29,8 @@
     $Id$
 */
 
-/// \file autoscan_inotify.cc
+/// @file autoscan_inotify.cc
+/// @brief Implement manager class for autoscan directories with inotify
 #define GRB_LOG_FAC GrbLogFacility::autoscan
 
 #ifdef HAVE_INOTIFY
@@ -42,16 +43,12 @@
 #include "content/content.h"
 #include "content/inotify/directory_watch.h"
 #include "content/inotify/inotify_handler.h"
-#include "content/inotify/mt_inotify.h"
+#include "content/inotify/inotify_manager_cc.h"
 #include "content/inotify/watch.h"
 #include "context.h"
 #include "database/database.h"
-#include "util/tools.h"
 
-#include <algorithm>
-#include <sys/inotify.h>
-
-#define INOTIFY_MAX_USER_WATCHES_FILE "/proc/sys/fs/inotify/max_user_watches"
+template void InotifyManager<DirectoryWatch>::run();
 
 AutoscanInotify::AutoscanInotify(const std::shared_ptr<Content>& content)
     : config(content->getContext()->getConfig())
@@ -60,54 +57,15 @@ AutoscanInotify::AutoscanInotify(const std::shared_ptr<Content>& content)
 {
     defFollowSymlinks = this->config->getBoolOption(ConfigVal::IMPORT_FOLLOW_SYMLINKS);
     defHidden = this->config->getBoolOption(ConfigVal::IMPORT_HIDDEN_FILES);
-    std::error_code ec;
-    if (isRegularFile(INOTIFY_MAX_USER_WATCHES_FILE, ec)) {
-        try {
-            [[maybe_unused]] int maxWatches = std::stoi(trimString(GrbFile(INOTIFY_MAX_USER_WATCHES_FILE).readTextFile()));
-            log_debug("Max watches on the system: {}", maxWatches);
-        } catch (const std::runtime_error& ex) {
-            log_error("Could not determine maximum number of inotify user watches: {}", ex.what());
-        }
-    }
 
-    shutdownFlag = true;
-    events = IN_CLOSE_WRITE | IN_CREATE | IN_MOVED_FROM | IN_MOVED_TO | IN_DELETE | IN_DELETE_SELF | IN_MOVE_SELF | IN_UNMOUNT;
     if (this->config->getBoolOption(ConfigVal::IMPORT_AUTOSCAN_INOTIFY_ATTRIB))
         events |= IN_ATTRIB;
 }
 
-AutoscanInotify::~AutoscanInotify()
-{
-    std::unique_lock<std::mutex> lock(mutex);
-    if (!shutdownFlag) {
-        log_debug("start");
-        shutdownFlag = true;
-        inotify->stop();
-        lock.unlock();
-        thread_.join();
-        log_debug("inotify thread died.");
-        inotify = nullptr;
-        watches.clear();
-    }
-}
-
-void AutoscanInotify::run()
-{
-    AutoLock lock(mutex);
-
-    if (shutdownFlag) {
-        shutdownFlag = false;
-        inotify = std::make_unique<Inotify>();
-        thread_ = std::thread([this] { threadProc(); });
-    }
-}
-
-/// \brief main proc for thread
 void AutoscanInotify::threadProc()
 {
     std::error_code ec;
     auto importMode = EnumOption<ImportMode>::getEnumOption(config, ConfigVal::IMPORT_LAYOUT_MODE);
-    AutoScanSetting asSetting;
     while (!shutdownFlag) {
         try {
             std::unique_lock<std::mutex> lock(mutex);
@@ -199,6 +157,7 @@ void AutoscanInotify::threadProc()
 
                 handler.doMove(wdObj);
 
+                AutoScanSetting asSetting;
                 asSetting.adir = adir;
                 asSetting.followSymlinks = adir ? adir->getFollowSymlinks() : defFollowSymlinks;
                 asSetting.recursive = adir ? adir->getRecursive() : false;
@@ -211,17 +170,18 @@ void AutoscanInotify::threadProc()
                 // changed
                 if (adir && handler.hasEvent()) {
                     // not new
-                    int wd = handler.doExistingFile(database, content, wdObj, importMode, isDir);
+                    int wd = handler.doExistingEntry(database, content, wdObj, importMode, isDir);
                     if (wd > INOTIFY_ROOT)
                         inotify->removeWatch(wd);
                     // new file
-                    handler.doNewFile(asSetting, content, isDir);
+                    handler.doNewEntry(asSetting, content, isDir);
                 }
                 // target is directory
                 if (isDir) {
                     handler.doDirectory(asSetting, content, wdObj);
                 }
                 handler.doIgnored();
+                log_debug("end event {}", event->wd);
             }
         } catch (const std::runtime_error& e) {
             log_error("Inotify thread caught exception: {}", e.what());
@@ -266,8 +226,8 @@ int AutoscanInotify::watchPathForMoves(const fs::path& path, int wd, unsigned in
 
     fs::path parent = path.parent_path();
     fs::path watchPath;
-    for (auto it = parent.begin(); it != parent.end(); ++it) {
-        watchPath /= *it;
+    for (const auto& it : parent) {
+        watchPath /= it;
         log_debug("adding move watch: {}", watchPath.c_str());
         parentWd = addMoveWatch(watchPath, wd, parentWd, retryCount);
     }
@@ -364,7 +324,7 @@ void AutoscanInotify::checkMoveWatches(int wd, const std::shared_ptr<DirectoryWa
                         content->handlePeristentAutoscanRemove(adir);
                     }
 
-                    auto object = database->findObjectByPath(path, DbFileType::File);
+                    auto object = database->findObjectByPath(path, UNUSED_CLIENT_GROUP, DbFileType::File);
                     if (object)
                         content->removeObject(adir, object, path, false);
                 }
@@ -461,7 +421,12 @@ std::shared_ptr<DirectoryWatch> AutoscanInotify::monitorUnmonitorRecursive(const
     return (result > INOTIFY_ROOT) ? watches.at(result) : nullptr;
 }
 
-int AutoscanInotify::monitorDirectory(const fs::path& path, const std::shared_ptr<AutoscanDirectory>& adir, bool isStartPoint, bool hasNonExisting, const fs::path& nonExistingPath)
+int AutoscanInotify::monitorDirectory(
+    const fs::path& path,
+    const std::shared_ptr<AutoscanDirectory>& adir,
+    bool isStartPoint,
+    bool hasNonExisting,
+    const fs::path& nonExistingPath)
 {
     int wd = inotify->addWatch(path, events, adir->getRetryCount());
 
