@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -39,8 +39,9 @@
 
 JSLayout::JSLayout(const std::shared_ptr<Content>& content, const std::string& parent)
     : Layout(content)
-    , import_script(std::make_unique<ImportScript>(content, parent))
+    , import_script(std::make_shared<ImportScript>(content, parent))
 {
+    import_script->init();
 }
 
 void JSLayout::processCdsObject(const std::shared_ptr<CdsObject>& obj,
