@@ -4,7 +4,7 @@
 
     curl_online_service.cc - this file is part of Gerbera.
 
-    Copyright (C) 2021-2024 Gerbera Contributors
+    Copyright (C) 2021-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -96,7 +96,11 @@ std::unique_ptr<pugi::xml_document> CurlOnlineService::getData()
 
     log_debug("GOT BUFFER {}", buffer);
     auto doc = std::make_unique<pugi::xml_document>();
-    pugi::xml_parse_result result = doc->load_string(sc->convert(buffer).c_str());
+    auto [mval, err] = sc->convert(buffer);
+    if (!err.empty()) {
+        log_warning("{}: {}", service_url, err);
+    }
+    pugi::xml_parse_result result = doc->load_string(mval.c_str());
     if (result.status != pugi::xml_parse_status::status_ok) {
         log_error("Error parsing {} XML: {}", serviceName, result.description());
         return nullptr;
@@ -140,7 +144,7 @@ bool CurlOnlineService::refreshServiceData(const std::shared_ptr<Layout>& layout
         obj->setVirtual(true);
 
         auto item = std::static_pointer_cast<CdsItem>(obj);
-        auto old = database->loadObjectByServiceID(item->getServiceID());
+        auto old = database->loadObjectByServiceID(item->getServiceID(), DEFAULT_CLIENT_GROUP);
         if (!old) {
             log_debug("Adding new {} object", serviceName);
 
