@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -36,12 +36,10 @@
 #include "import_script.h" // API
 
 #include "cds/cds_objects.h"
-#include "common.h"
 #include "config/config_val.h"
 #include "config/result/autoscan.h"
 #include "content/content.h"
 #include "context.h"
-#include "js_functions.h"
 #include "util/string_converter.h"
 #include "util/tools.h"
 
