@@ -44,6 +44,7 @@
 #include "config/setup/config_setup_autoscan.h"
 #include "config/setup/config_setup_boxlayout.h"
 #include "config/setup/config_setup_dictionary.h"
+#include "config/setup/config_setup_enum.h"
 #include "content/autoscan_setting.h"
 #include "content/content.h"
 #include "context.h"
@@ -132,7 +133,10 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
     _m2i = converterManager->m2i(ConfigVal::IMPORT_METADATA_CHARSET, "");
     _f2i = converterManager->f2i();
     _i2i = converterManager->i2i();
+}
 
+void Script::init()
+{
     duk_push_thread_stash(ctx, ctx);
     duk_push_pointer(ctx, this);
     duk_put_prop_string(ctx, -2, "this");
@@ -237,7 +241,7 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
                 setIntProperty(definition->removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_SCANCOUNT), adir->getActiveScanCount());
                 setIntProperty(definition->removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_TASKCOUNT), adir->getTaskCount());
                 setIntProperty(definition->removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_RETRYCOUNT), adir->getRetryCount());
-                setProperty(definition->removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_LMT), fmt::format("{:%Y-%m-%d %H:%M:%S}", fmt::localtime(adir->getPreviousLMT().count())));
+                setProperty(definition->removeAttribute(ConfigVal::A_AUTOSCAN_DIRECTORY_LMT), grbLocaltime("{:%Y-%m-%d %H:%M:%S}", adir->getPreviousLMT()));
 
                 duk_put_prop_string(ctx, -2, fmt::to_string(adir->getScanID()).c_str());
                 log_debug("Adding config[{}][{}] {}", autoscanItemPath, adir->getScanID(), adir->getLocation().string());
@@ -248,29 +252,67 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
         log_debug("Adding config[{}] {}", autoscanItemPath, idx);
     }
 
+    auto&& boxSetup = definition->findConfigSetup<ConfigSetup>(ConfigVal::A_BOXLAYOUT_BOX);
+    auto&& chainSetup = definition->findConfigSetup<ConfigSetup>(ConfigVal::A_BOXLAYOUT_CHAIN);
+    auto&& typeSetup = definition->findConfigSetup<ConfigEnumSetup<AutoscanMediaMode>>(ConfigVal::A_BOXLAYOUT_CHAIN_TYPE);
     for (auto&& bcs : definition->getConfigSetupList<ConfigBoxLayoutSetup>()) {
-        duk_push_object(ctx); // box-layout
         auto boxLayoutList = bcs->getValue()->getBoxLayoutListOption();
-        for (std::size_t i = 0; i < boxLayoutList->size(); i++) {
+
+        duk_push_object(ctx); // box-layout
+        for (std::size_t i = 0; i < EDIT_CAST(EditHelperBoxLayout, boxLayoutList)->size(); i++) {
             duk_push_object(ctx);
-            auto boxLayout = boxLayoutList->get(i);
+            auto boxLayout = EDIT_CAST(EditHelperBoxLayout, boxLayoutList)->get(i);
             setIntProperty("id", boxLayout->getId());
             setIntProperty(definition->removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_SIZE), boxLayout->getSize());
             setBoolProperty(definition->removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_ENABLED), boxLayout->getEnabled());
             setProperty(definition->removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_TITLE), boxLayout->getTitle());
             setProperty(definition->removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_CLASS), boxLayout->getClass());
             setProperty(definition->removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_UPNP_SHORTCUT), boxLayout->getUpnpShortcut());
+            setProperty(definition->removeAttribute(ConfigVal::A_BOXLAYOUT_BOX_SORT_KEY), boxLayout->getSortKey());
             duk_put_prop_string(ctx, -2, boxLayout->getKey().c_str());
         }
-        std::string boxLayoutItemPath = bcs->getItemPathRoot(true); // prefix
+        std::string boxLayoutItemPath = fmt::format("{}/{}", bcs->getItemPathRoot(true), boxSetup->getItemPathRoot(true));
+        log_debug("Adding box config[{}] {}", boxLayoutItemPath, EDIT_CAST(EditHelperBoxLayout, boxLayoutList)->size());
         duk_put_prop_string(ctx, -2, boxLayoutItemPath.c_str()); // box-layout
-        log_debug("Adding config[{}] {}", boxLayoutItemPath, boxLayoutList->size());
+
+        for (auto&& type : { AutoscanMediaMode::Audio, AutoscanMediaMode::Image, AutoscanMediaMode::Video }) {
+            duk_push_object(ctx); // chain-layout
+            std::size_t size = 0;
+            for (std::size_t i = 0; i < EDIT_CAST(EditHelperBoxChain, boxLayoutList)->size(); i++) {
+                auto&& chain = EDIT_CAST(EditHelperBoxChain, boxLayoutList)->get(i);
+                if (chain->getType() == type) {
+                    duk_push_object(ctx);
+                    setIntProperty("index", chain->getIndex());
+                    setIntProperty("size", chain->getLinksSize());
+                    auto&& links = chain->getLinks();
+                    for (std::size_t j = 0; j < links.size(); j++) {
+                        duk_push_object(ctx);
+                        auto&& link = links.at(j);
+                        for (auto&& [key, value] : link) {
+                            setProperty(key, value);
+                        }
+                        duk_put_prop_string(ctx, -2, fmt::to_string(j).c_str());
+                    }
+                    duk_put_prop_string(ctx, -2, fmt::to_string(chain->getIndex()).c_str());
+                    ++size;
+                }
+            }
+            setIntProperty("size", size);
+            std::string chainLayoutItemPath = fmt::format("{}/{}/{}", bcs->getItemPathRoot(true), chainSetup->getItemPathRoot(true), typeSetup->mapEnumValue(type));
+            log_debug("Adding chain config[{}] {}", chainLayoutItemPath, EDIT_CAST(EditHelperBoxChain, boxLayoutList)->size());
+            duk_put_prop_string(ctx, -2, chainLayoutItemPath.c_str()); // chain-layout
+        }
     }
 
     duk_put_global_string(ctx, "config");
 
     defineFunctions(jsGlobalFunctions.data());
+    loadContent();
+    runtime->addScript(shared_from_this());
+}
 
+void Script::loadContent()
+{
     std::string commonScrPath = config->getOption(ConfigVal::IMPORT_SCRIPTING_COMMON_SCRIPT);
     std::string commonFdrPath = config->getOption(ConfigVal::IMPORT_SCRIPTING_COMMON_FOLDER);
 
@@ -286,6 +328,7 @@ Script::Script(const std::shared_ptr<Content>& content, const std::string& paren
             log_error("Unable to load {}: {}", commonScrPath, e.what());
         }
     }
+
     std::string customScrPath = config->getOption(ConfigVal::IMPORT_SCRIPTING_CUSTOM_SCRIPT);
     std::string customFdrPath = config->getOption(ConfigVal::IMPORT_SCRIPTING_CUSTOM_FOLDER);
     if (!customScrPath.empty()) {
@@ -543,7 +586,14 @@ std::vector<int> Script::call(const std::shared_ptr<CdsObject>& obj,
 
 void Script::setMetaData(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsItem>& item, const std::string& sym, const std::string& val) const
 {
-    if (sym == MetaEnumMapper::getMetaFieldName(MetadataFields::M_TRACKNUMBER) && item) {
+    if (sym == DC_TITLE)
+        obj->setTitle(val);
+
+    if (sym == UPNP_SEARCH_CLASS) {
+        obj->setClass(val);
+    } else if (sym == "mimetype" && item) {
+        item->setMimeType(val);
+    } else if (sym == MetaEnumMapper::getMetaFieldName(MetadataFields::M_TRACKNUMBER) && item) {
         int j = stoiString(val, 0);
         if (j > 0) {
             item->addMetaData(sym, val);
@@ -583,13 +633,13 @@ std::shared_ptr<CdsObject> Script::createObject(const std::shared_ptr<CdsObject>
     if (id != INVALID_OBJECT_ID) {
         obj->setID(id);
     }
-    id = ScriptNamedProperty(ctx, "refID").getIntValue(INVALID_OBJECT_ID);
-    if (id != INVALID_OBJECT_ID) {
-        obj->setRefID(id);
+    int refId = ScriptNamedProperty(ctx, "refID").getIntValue(INVALID_OBJECT_ID);
+    if (refId != INVALID_OBJECT_ID && refId != id) {
+        obj->setRefID(refId);
     }
-    id = ScriptNamedProperty(ctx, "parentID").getIntValue(INVALID_OBJECT_ID);
-    if (id != INVALID_OBJECT_ID) {
-        obj->setParentID(id);
+    int parentID = ScriptNamedProperty(ctx, "parentID").getIntValue(INVALID_OBJECT_ID);
+    if (parentID != INVALID_OBJECT_ID) {
+        obj->setParentID(parentID);
     }
 
     ScriptNamedProperty(ctx, "parent").getObject([&]() {
@@ -706,6 +756,19 @@ std::shared_ptr<CdsObject> Script::dukObject2cdsObject(const std::shared_ptr<Cds
             obj->setTitle(pcd->getTitle());
         }
     }
+    // update sortKey
+    {
+        auto val = ScriptNamedProperty(ctx, "sortKey").getStringValue();
+        if (!val.empty()) {
+            auto [mval, err] = sc->convert(val);
+            if (!err.empty()) {
+                log_warning("{}: {}", obj->getLocation().string(), err);
+            }
+            obj->setSortKey(mval);
+        } else {
+            obj->setSortKey(obj->getTitle());
+        }
+    }
 
     // update upnpclass
     {
@@ -892,6 +955,7 @@ void Script::cdsObject2dukObject(const std::shared_ptr<CdsObject>& obj)
     setIntProperty("parentID", obj->getParentID(), INVALID_OBJECT_ID);
 
     setProperty("title", obj->getTitle(), false);
+    setProperty("sortKey", obj->getSortKey(), false);
     setProperty("upnpclass", obj->getClass(), false);
     setProperty("location", obj->getLocation(), false);
 
