@@ -26,9 +26,10 @@
 
 #include "script_property.h" // API
 
-#include "util/logger.h"
 #include "util/tools.h"
 
+ScriptProperty::~ScriptProperty() = default;
+
 std::vector<std::string> ScriptProperty::getStringArrayValue() const
 {
     std::vector<std::string> result;
