@@ -54,10 +54,10 @@ Sqlite3Database::Sqlite3Database(const std::shared_ptr<Config>& config, const st
     table_quote_end = '"';
 
     // if sqlite3.sql or sqlite3-upgrade.xml is changed hashies have to be updated
-    hashies = { 2195679403, // index 0 is used for create script sqlite3.sql = Version 1
-        778996897, 3362507034, 853149842, 4035419264, 3497064885, 974692115, 119767663, 3167732653, 2427825904, 3305506356, // upgrade 2-11
-        43189396, 2767540493, 2512852146, 1273710965, 319062951, 3593597366, 1028160353, 881071639, 1989518047, 3743992560, // upgrade 12-21
-        3135921396, 3108208 };
+    hashies = { 2771697970, // index 0 is used for create script sqlite3.sql = Version 1
+        778996897, 3362507034, 853149842, 2776802417, 3497064885, 974692115, 119767663, 3167732653, 2427825904, 3305506356, // upgrade 2-11
+        3908767237, 509765404, 2512852146, 1273710965, 319062951, 2316641127, 1028160353, 881071639, 1989518047, 782849313, // upgrade 12-21
+        3135921396, 3108208, 2156790525 };
 }
 
 void Sqlite3Database::prepare()
@@ -102,10 +102,13 @@ std::string Sqlite3Database::prepareDatabase(const fs::path& dbFilePath, GrbFile
 
     if (dbVersion.empty() && !dbBackupFile.isReadable()) {
         log_info("No sqlite3 backup is available or backup is corrupt. Automatically creating new database file...");
-        auto itask = std::make_shared<SLInitTask>(config, hashies[0]);
+        auto itask = std::make_shared<SLInitTask>(config, hashies[0], stringLimit);
         addTask(itask);
         try {
             itask->waitForTask();
+            fillDatabase();
+            storeInternalSetting("string_limit", fmt::to_string(stringLimit));
+            storeInternalSetting("resource_attribute", "");
             prepare();
             dbFile.setPermissions();
             dbVersion = getInternalSetting("db_version");
@@ -113,7 +116,7 @@ std::string Sqlite3Database::prepareDatabase(const fs::path& dbFilePath, GrbFile
             shutdown();
             throw_std_runtime_error("Error while creating database: {}", e.what());
         }
-        log_info("database created successfully.");
+        log_info("Database {} created successfully.", dbFilePath.c_str());
     }
 
     if (dbVersion.empty()) {
@@ -171,18 +174,32 @@ void Sqlite3Database::init()
             btask->waitForTask();
 
             // add timer for backups
-            auto backupInterval = std::chrono::seconds(config->getIntOption(ConfigVal::SERVER_STORAGE_SQLITE_BACKUP_INTERVAL));
+            auto backupInterval = std::chrono::seconds(config->getLongOption(ConfigVal::SERVER_STORAGE_SQLITE_BACKUP_INTERVAL));
             timer->addTimerSubscriber(this, backupInterval, nullptr);
             hasBackupTimer = true;
         }
+
+        auto dbLimit = getInternalSetting("string_limit");
+        if (!dbLimit.empty() && std::stoul(dbLimit) > stringLimit)
+            log_warning("Your database was created with string length {} but your current config value is {}", dbLimit, stringLimit);
+        else if (dbLimit.empty()) {
+            log_info("Saving string limit {}", stringLimit);
+            storeInternalSetting("string_limit", fmt::to_string(stringLimit));
+        }
         dbInitDone = true;
     } catch (const std::runtime_error& e) {
-        log_error("prematurely shutting down.");
+        log_error("Prematurely shutting down.");
         shutdown();
         throw_std_runtime_error(e.what());
     }
 
-    initDynContainers();
+    try {
+        initDynContainers();
+    } catch (const std::runtime_error& e) {
+        log_error("Prematurely shutting down because of initDynContainers.");
+        shutdown();
+        throw_std_runtime_error(e.what());
+    }
 }
 
 std::shared_ptr<Database> Sqlite3Database::getSelf()
@@ -248,7 +265,7 @@ void Sqlite3DatabaseWithTransactions::commit(std::string_view tName)
     }
 }
 
-void Sqlite3Database::handleException(const std::runtime_error& exc, const std::string& lineMessage)
+void Sqlite3Database::handleException(const std::exception& exc, const std::string& lineMessage)
 {
     if (!dbInitDone)
         throw_std_runtime_error(exc.what());
@@ -383,6 +400,8 @@ void Sqlite3Database::threadProc()
                     task->sendSignal();
                 } catch (const std::runtime_error& e) {
                     task->sendSignal(e.what());
+                } catch (const std::logic_error& e) {
+                    task->sendSignal(e.what());
                 }
                 lock.lock();
             }
