@@ -43,7 +43,11 @@ class Exiv2Handler : public MediaMetadataHandler {
 public:
     explicit Exiv2Handler(const std::shared_ptr<Context>& context);
 
-    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    bool isSupported(const std::string& contentType,
+        bool isOggTheora,
+        const std::string& mimeType,
+        ObjectType mediaType) override;
+    bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
     std::unique_ptr<IOHandler> serveContent(
         const std::shared_ptr<CdsObject>& obj,
         const std::shared_ptr<CdsResource>& resource) override;
