@@ -51,6 +51,7 @@ class CdsItem;
 class FfmpegObject;
 class IOHandler;
 struct AVFormatContext;
+struct AVDictionaryEntry;
 class StringConverter;
 
 /// \brief This class is responsible for reading id3 tags metadata
@@ -58,7 +59,11 @@ class FfmpegHandler : public MediaMetadataHandler {
 public:
     explicit FfmpegHandler(const std::shared_ptr<Context>& context);
 
-    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    bool isSupported(const std::string& contentType,
+        bool isOggTheora,
+        const std::string& mimeType,
+        ObjectType mediaType) override;
+    bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
     std::unique_ptr<IOHandler> serveContent(
         const std::shared_ptr<CdsObject>& obj,
         const std::shared_ptr<CdsResource>& resource) override;
@@ -66,21 +71,30 @@ public:
 
 private:
     /// \brief get all AUX values as configured
-    void addFfmpegAuxdataFields(
+    bool addFfmpegAuxdataFields(
         const std::shared_ptr<CdsItem>& item,
         const FfmpegObject& ffmpegObject) const;
     /// \brief get all metadata fields
-    void addFfmpegMetadataFields(
+    bool addFfmpegMetadataFields(
         const std::shared_ptr<CdsItem>& item,
         const FfmpegObject& ffmpegObject) const;
+    /// \brief get one metadata field
+    bool getFfmpegMetadataField(
+        const std::shared_ptr<CdsItem>& item,
+        const FfmpegObject& ffmpegObject,
+        AVDictionaryEntry* avEntry,
+        std::map<MetadataFields, bool>& emptyProperties,
+        std::map<std::string, bool>& emptySpecProperties) const;
     /// \brief get additional resource fields
-    static void addFfmpegResourceFields(
+    bool addFfmpegResourceFields(
         const std::shared_ptr<CdsItem>& item,
         const FfmpegObject& ffmpegObject);
     /// \brief fabricate comment from metadata
-    void addFfmpegComment(
+    bool addFfmpegComment(
         const std::shared_ptr<CdsItem>& item,
         const FfmpegObject& ffmpegObject) const;
+    /// \brief try to extract mime type and content type from stream data
+    std::string getContentTypeFromByteVector(const std::vector<std::uint8_t>& data) const;
 
     static constexpr std::array propertyMap {
         std::pair(MetadataFields::M_TITLE, "title"),
@@ -95,6 +109,8 @@ private:
         std::pair(MetadataFields::M_DATE, "date"),
         std::pair(MetadataFields::M_CREATION_DATE, "creation_time"),
     };
+    /// \brief activate separation of artwork found by handler
+    bool artWorkEnabled;
 };
 
 #endif // HAVE_FFMPEG
