@@ -118,13 +118,23 @@ MatroskaHandler::MatroskaHandler(const std::shared_ptr<Context>& context)
 {
 }
 
-void MatroskaHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
+bool MatroskaHandler::isSupported(
+    const std::string& contentType,
+    bool isOggTheora,
+    const std::string& mimeType,
+    ObjectType mediaType)
+{
+    return contentType == CONTENT_TYPE_MKV;
+}
+
+bool MatroskaHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
     if (!item || !isEnabled)
-        return;
+        return false;
 
     parseMKV(item, nullptr);
+    return activeFlag == 0;
 }
 
 std::unique_ptr<IOHandler> MatroskaHandler::serveContent(
@@ -345,7 +355,7 @@ public:
     template <class MkvKey>
     std::string getDate(EbmlElement* el)
     {
-        MkvKey* dateEl = dynamic_cast<MkvKey*>(el);
+        auto dateEl = dynamic_cast<MkvKey*>(el);
         if (!dateEl)
             return "";
 
@@ -363,7 +373,7 @@ public:
     template <class MkvKey>
     std::string getString(EbmlElement* el)
     {
-        MkvKey* elValue = dynamic_cast<MkvKey*>(el);
+        auto elValue = dynamic_cast<MkvKey*>(el);
         if (!elValue)
             return "";
 
