@@ -49,12 +49,18 @@ class MemIOHandler;
 class MatroskaHandler : public MediaMetadataHandler {
 public:
     explicit MatroskaHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+
+    bool isSupported(const std::string& contentType,
+        bool isOggTheora,
+        const std::string& mimeType,
+        ObjectType mediaType) override;
+    bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
     std::unique_ptr<IOHandler> serveContent(
         const std::shared_ptr<CdsObject>& obj,
         const std::shared_ptr<CdsResource>& resource) override;
 
 private:
+    /// \brief indicate that search for item is still active
     int activeFlag {};
     std::map<std::string, std::string> mkvTags;
 
