@@ -34,15 +34,26 @@
 
 class ConfigDefinition;
 class Content;
+class Database;
 class StringConverter;
 
+/// \brief This class is responsible for expanding configuration options to file names
 class ContentPathSetup {
 public:
-    explicit ContentPathSetup(std::shared_ptr<Config> config, const std::shared_ptr<ConfigDefinition>& definition, ConfigVal fileListOption, ConfigVal dirListOption);
-    std::vector<fs::path> getContentPath(const std::shared_ptr<CdsObject>& obj, const std::string& setting, fs::path folder = "") const;
+    explicit ContentPathSetup(
+        std::shared_ptr<Config> config,
+        std::shared_ptr<Database> database,
+        const std::shared_ptr<ConfigDefinition>& definition,
+        ConfigVal fileListOption,
+        ConfigVal dirListOption);
+    std::vector<fs::path> getContentPath(
+        const std::shared_ptr<CdsObject>& obj,
+        const std::string& setting,
+        fs::path folder = "") const;
 
 private:
     std::shared_ptr<Config> config;
+    std::shared_ptr<Database> database;
     std::vector<std::string> names;
     std::vector<std::vector<std::pair<std::string, std::string>>> patterns;
     std::shared_ptr<DirectoryConfigList> allTweaks;
@@ -55,18 +66,27 @@ private:
 class MetacontentHandler : public MetadataHandler {
 public:
     explicit MetacontentHandler(const std::shared_ptr<Context>& context);
+    ~MetacontentHandler() override;
 
 protected:
     const std::shared_ptr<StringConverter> f2i;
     std::shared_ptr<ConfigDefinition> definition;
+    std::shared_ptr<Database> database;
 };
 
 /// \brief This class is responsible for populating filesystem based album and fan art
 class FanArtHandler : public MetacontentHandler {
 public:
     explicit FanArtHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
-    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsResource>& resource) override;
+
+    bool isSupported(const std::string& contentType,
+        bool isOggTheora,
+        const std::string& mimeType,
+        ObjectType mediaType) override;
+    bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(
+        const std::shared_ptr<CdsObject>& obj,
+        const std::shared_ptr<CdsResource>& resource) override;
 
 private:
     static std::unique_ptr<ContentPathSetup> setup;
@@ -76,8 +96,10 @@ private:
 class ContainerArtHandler : public MetacontentHandler {
 public:
     explicit ContainerArtHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
-    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsResource>& resource) override;
+    bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(
+        const std::shared_ptr<CdsObject>& obj,
+        const std::shared_ptr<CdsResource>& resource) override;
 
 private:
     static std::unique_ptr<ContentPathSetup> setup;
@@ -87,8 +109,15 @@ private:
 class SubtitleHandler : public MetacontentHandler {
 public:
     explicit SubtitleHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
-    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsResource>& resource) override;
+
+    bool isSupported(const std::string& contentType,
+        bool isOggTheora,
+        const std::string& mimeType,
+        ObjectType mediaType) override;
+    bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(
+        const std::shared_ptr<CdsObject>& obj,
+        const std::shared_ptr<CdsResource>& resource) override;
 
 private:
     static std::unique_ptr<ContentPathSetup> setup;
@@ -98,8 +127,10 @@ private:
 class MetafileHandler : public MetacontentHandler {
 public:
     explicit MetafileHandler(const std::shared_ptr<Context>& context, std::shared_ptr<Content> content);
-    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
-    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsResource>& resource) override;
+    bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(
+        const std::shared_ptr<CdsObject>& obj,
+        const std::shared_ptr<CdsResource>& resource) override;
 
 private:
     static std::unique_ptr<ContentPathSetup> setup;
@@ -110,8 +141,10 @@ private:
 class ResourceHandler : public MetacontentHandler {
 public:
     explicit ResourceHandler(const std::shared_ptr<Context>& context);
-    void fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
-    std::unique_ptr<IOHandler> serveContent(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsResource>& resource) override;
+    bool fillMetadata(const std::shared_ptr<CdsObject>& obj) override;
+    std::unique_ptr<IOHandler> serveContent(
+        const std::shared_ptr<CdsObject>& obj,
+        const std::shared_ptr<CdsResource>& resource) override;
 
 private:
     static std::unique_ptr<ContentPathSetup> setup;
