@@ -56,7 +56,8 @@ static const auto propertyMap = std::map<std::string_view, MetadataFields> {
 
 #define MAX_WV_TEXT_SIZE 256
 #define MAX_WV_IMAGE_SIZE 1024 * 1024
-#define ALBUMART_OPTION "albumArtTag"
+#define ATTACHMENT_OPTION "albumArtTag"
+#define ARTWORK_TAG "Cover"
 
 WavPackHandler::WavPackHandler(const std::shared_ptr<Context>& context)
     : MediaMetadataHandler(
@@ -75,11 +76,20 @@ WavPackHandler::~WavPackHandler()
         context = WavpackCloseFile(context);
 }
 
-void WavPackHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
+bool WavPackHandler::isSupported(
+    const std::string& contentType,
+    bool isOggTheora,
+    const std::string& mimeType,
+    ObjectType mediaType)
+{
+    return contentType == CONTENT_TYPE_WAVPACK;
+}
+
+bool WavPackHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
     if (!item || !isEnabled)
-        return;
+        return false;
 
     char error[MAX_WV_TEXT_SIZE];
     /* WavpackContext * WavpackOpenFileInput (const char *inFileName, char *error, int flags, int norm_offset);
@@ -97,11 +107,12 @@ void WavPackHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
     WavpackContext* context = WavpackOpenFileInput(item->getLocation().c_str(), error, OPEN_TAGS | OPEN_2CH_MAX | OPEN_DSD_NATIVE, 0);
     if (!context) {
         log_error("Could not open {} as WavPack file: {}", item->getLocation().c_str(), error);
-        return;
+        return false;
     }
-    getAttributes(context, item);
-    getTags(context, item);
-    getAttachments(context, item);
+    bool result = false;
+    result = getAttributes(context, item) || result;
+    result = getTags(context, item) || result;
+    result = getAttachments(context, item) || result;
 
 #ifdef UNUSED_WAVPACK
     auto bytesPerSample = WavpackGetBytesPerSample(context);
@@ -150,9 +161,13 @@ void WavPackHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
     auto numSamples = WavpackGetNumSamples64(context);
     auto ratio = WavpackGetRatio(context);
 #endif
+
+    return result;
 }
 
-void WavPackHandler::getAttributes(WavpackContext* context, const std::shared_ptr<CdsItem>& item)
+bool WavPackHandler::getAttributes(
+    WavpackContext* context,
+    const std::shared_ptr<CdsItem>& item)
 {
     auto resource = item->getResource(ContentHandler::DEFAULT);
     auto nrChannels = WavpackGetNumChannels(context);
@@ -176,9 +191,12 @@ void WavPackHandler::getAttributes(WavpackContext* context, const std::shared_pt
     resource->addAttribute(ResourceAttribute::FORMAT, fileFormats.at(fileFormat).data());
     auto avgBitrate = WavpackGetAverageBitrate(context, 0);
     resource->addAttribute(ResourceAttribute::BITRATE, fmt::to_string(avgBitrate));
+    return true;
 }
 
-std::string WavPackHandler::getContentTypeFromByteVector(const char* data, int size) const
+std::string WavPackHandler::getMimeTypeFromByteVector(
+    const char* data,
+    int size) const
 {
 #ifdef HAVE_MAGIC
     auto artMimetype = mime->bufferToMimeType(data, size);
@@ -188,11 +206,14 @@ std::string WavPackHandler::getContentTypeFromByteVector(const char* data, int s
 #endif
 }
 
-void WavPackHandler::getAttachments(WavpackContext* context, const std::shared_ptr<CdsItem>& item)
+bool WavPackHandler::getAttachments(
+    WavpackContext* context,
+    const std::shared_ptr<CdsItem>& item)
 {
     auto tagCount = WavpackGetNumBinaryTagItems(context);
     char tag[MAX_WV_TEXT_SIZE];
     char value[MAX_WV_IMAGE_SIZE];
+    bool result = false;
     for (int index = 0; index < tagCount; index++) {
         auto size = WavpackGetBinaryTagItemIndexed(context, index, tag, MAX_WV_TEXT_SIZE);
         if (size > MAX_WV_TEXT_SIZE) {
@@ -203,27 +224,35 @@ void WavPackHandler::getAttachments(WavpackContext* context, const std::shared_p
                 log_warning("file {}: wavpack binary tag {} value '{}' truncated (full size {})", item->getLocation().c_str(), tag, value, size);
                 size = MAX_WV_IMAGE_SIZE;
             }
-            if (startswith(tag, "Cover Art")) {
-                log_debug("Identified metadata '{}': {}", tag, value);
+            auto attmtMimetype = getMimeTypeFromByteVector(value + strlen(value) + 1, size - strlen(value) - 1);
+            auto protocolInfo = renderProtocolInfo(attmtMimetype);
+            log_debug("Identified metadata '{}': {}", tag, value);
+            if (startswith(tag, ARTWORK_TAG)) {
 
                 /* The convention for binary tag items in APEv2 tags is that the data starts with a NULLterminated
                    string representing a filename. After the terminating NULL, the actual binary data
                    starts. In the WavPack code this filename has only the extension of the actual file; the name
                    portion is made up of the tag item name.
                 */
-                auto artMimetype = getContentTypeFromByteVector(value + strlen(value) + 1, size - strlen(value) - 1);
-                if (artMimetype != MIMETYPE_DEFAULT) {
-                    log_debug("Adding resource '{}'", renderProtocolInfo(artMimetype));
-                    auto resource = std::make_shared<CdsResource>(ContentHandler::WAVPACK, ResourcePurpose::Thumbnail);
-                    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo(artMimetype));
-                    resource->addOption(ALBUMART_OPTION, tag);
-                    item->addResource(resource);
-                }
+                log_debug("Adding album art '{}'", protocolInfo);
+                auto resource = std::make_shared<CdsResource>(ContentHandler::WAVPACK, ResourcePurpose::Thumbnail);
+                if (attmtMimetype != MIMETYPE_DEFAULT)
+                    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, protocolInfo);
+                resource->addOption(ATTACHMENT_OPTION, tag);
+                item->addResource(resource);
+                result = true;
             } else {
                 log_warning("file {}: wavpack binary tag {} unknown", item->getLocation().c_str(), tag);
+                log_debug("Adding resource '{}'", protocolInfo);
+                auto resource = std::make_shared<CdsResource>(ContentHandler::WAVPACK, ResourcePurpose::Content);
+                resource->addAttribute(ResourceAttribute::PROTOCOLINFO, protocolInfo);
+                resource->addOption(ATTACHMENT_OPTION, tag);
+                item->addResource(resource);
+                result = true;
             }
         }
     }
+    return result;
 }
 
 /// \brief Wrapper class to interface with libwavpack
@@ -237,7 +266,11 @@ private:
 public:
     char tag[MAX_WV_TEXT_SIZE] { '\0' };
 
-    WavPackObject(WavpackContext* context, int index, const std::shared_ptr<StringConverter> sc, const std::shared_ptr<CdsItem>& item)
+    WavPackObject(
+        WavpackContext* context,
+        int index,
+        const std::shared_ptr<StringConverter>& sc,
+        const std::shared_ptr<CdsItem>& item)
         : location(item->getLocation())
         , sc(sc)
     {
@@ -287,11 +320,14 @@ public:
     }
 };
 
-void WavPackHandler::getTags(WavpackContext* context, const std::shared_ptr<CdsItem>& item)
+bool WavPackHandler::getTags(
+    WavpackContext* context,
+    const std::shared_ptr<CdsItem>& item)
 {
     auto sc = converterManager->m2i(ConfigVal::IMPORT_LIBOPTS_WAVPACK_CHARSET, item->getLocation());
     auto tagCount = WavpackGetNumTagItems(context);
     std::vector<std::string> snippets;
+    bool result = false;
     for (int index = 0; index < tagCount; index++) {
         WavPackObject wavpackObject(context, index, sc, item);
         if (wavpackObject) {
@@ -303,6 +339,7 @@ void WavPackHandler::getTags(WavpackContext* context, const std::shared_ptr<CdsI
                         log_debug("Identified metadata '{}': {}", wavpackObject.tag, dateValue);
                         item->addMetaData(MetadataFields::M_DATE, fmt::format("{}-01-01", dateValue));
                         item->addMetaData(MetadataFields::M_UPNP_DATE, fmt::format("{}-01-01", dateValue));
+                        result = true;
                     }
                 } else {
                     log_warning("file {}: wavpack tag {} unknown", item->getLocation().string(), wavpackObject.tag);
@@ -313,6 +350,7 @@ void WavPackHandler::getTags(WavpackContext* context, const std::shared_ptr<CdsI
                     log_debug("Identified metadata '{}': {}", wavpackObject.tag, val);
                     item->removeMetaData(propertyMap.at(wavpackObject.tag)); // wavpack tags overwrite existing values
                     item->addMetaData(propertyMap.at(wavpackObject.tag), val);
+                    result = true;
                 }
             }
             auto meta = metaTags.find(wavpackObject.tag);
@@ -322,6 +360,7 @@ void WavPackHandler::getTags(WavpackContext* context, const std::shared_ptr<CdsI
                     if (!dateValue.empty()) {
                         log_debug("Identified metadata '{}': {}", wavpackObject.tag, dateValue);
                         item->addMetaData(meta->first, fmt::format("{}-01-01", dateValue));
+                        result = true;
                     }
                 } else {
                     auto val = wavpackObject.getValue();
@@ -329,6 +368,7 @@ void WavPackHandler::getTags(WavpackContext* context, const std::shared_ptr<CdsI
                         log_debug("Identified metadata '{}': {}", wavpackObject.tag, val);
                         item->removeMetaData(metaTags.at(wavpackObject.tag)); // wavpack tags overwrite existing values
                         item->addMetaData(metaTags.at(wavpackObject.tag), val);
+                        result = true;
                     }
                 }
             }
@@ -338,6 +378,7 @@ void WavPackHandler::getTags(WavpackContext* context, const std::shared_ptr<CdsI
                 if (!val.empty()) {
                     log_debug("Identified auxdata '{}': {}", wavpackObject.tag, val);
                     item->setAuxData(wavpackObject.tag, val);
+                    result = true;
                 }
             }
             auto comment = std::find_if(commentMap.begin(), commentMap.end(), [&](auto& c) { return c.second == wavpackObject.tag; });
@@ -354,37 +395,41 @@ void WavPackHandler::getTags(WavpackContext* context, const std::shared_ptr<CdsI
         auto comment = fmt::format("{}", fmt::join(snippets, ", "));
         log_debug("Fabricated Comment: {}", comment);
         item->addMetaData(MetadataFields::M_DESCRIPTION, comment);
+        result = true;
     }
+    return result;
 }
 
-std::unique_ptr<IOHandler> WavPackHandler::serveContent(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<CdsResource>& resource)
+std::unique_ptr<IOHandler> WavPackHandler::serveContent(
+    const std::shared_ptr<CdsObject>& obj,
+    const std::shared_ptr<CdsResource>& resource)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
     if (!item) // not streamable
         return {};
     if (!resource)
         return {};
-    auto artTag = resource->getOption(ALBUMART_OPTION);
-    if (artTag.empty())
+    auto attmtTag = resource->getOption(ATTACHMENT_OPTION);
+    if (attmtTag.empty())
         return {};
 
-    char error[MAX_WV_TEXT_SIZE];
+    char error[MAX_WV_TEXT_SIZE] = { '\0' };
     context = WavpackOpenFileInput(item->getLocation().c_str(), error, OPEN_TAGS | OPEN_2CH_MAX | OPEN_DSD_NATIVE, 0);
     if (!context) {
         log_error("Could not open {} as WavPack file: {}", item->getLocation().c_str(), error);
     }
 
-    char value[MAX_WV_IMAGE_SIZE];
-    auto size = WavpackGetBinaryTagItem(context, artTag.c_str(), value, MAX_WV_IMAGE_SIZE);
+    char value[MAX_WV_IMAGE_SIZE] = { '\0' };
+    auto size = WavpackGetBinaryTagItem(context, attmtTag.c_str(), value, MAX_WV_IMAGE_SIZE);
     if (size > MAX_WV_IMAGE_SIZE) {
-        log_warning("file {}: wavpack binary tag {} value '{}' truncated (full size {})", item->getLocation().c_str(), artTag, value, size);
+        log_warning("file {}: wavpack binary tag {} value '{}' truncated (full size {})", item->getLocation().c_str(), attmtTag, value, size);
         size = MAX_WV_IMAGE_SIZE;
     }
-    if (startswith(artTag, "Cover Art")) {
-        log_debug("Found image '{}': {}", artTag, value);
+    if (startswith(attmtTag, ARTWORK_TAG)) {
+        log_debug("Found image '{}': {}", attmtTag, value);
         return std::make_unique<MemIOHandler>(value + strlen(value) + 1, size - strlen(value) - 1);
     }
-    log_warning("file {}: wavpack binary tag {} unknown", item->getLocation().c_str(), artTag);
+    log_warning("file {}: wavpack binary tag {} unknown", item->getLocation().c_str(), attmtTag);
 
     return {};
 }
