@@ -3,7 +3,7 @@ Gerbera - https://gerbera.io/
 
     grb_net.cc - this file is part of Gerbera.
 
-    Copyright (C) 2022-2024 Gerbera Contributors
+    Copyright (C) 2022-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -118,7 +118,7 @@ int GrbNet::getAdressFamily() const
 bool GrbNet::equals(const std::string& match) const
 {
     auto net = splitString(match, '/');
-    auto ip = net[0];
+    const auto& ip = net.front();
     if (ip.find(':') != std::string::npos) {
         auto prefix = stoiString(net.size() > 1 ? net[1] : "128", 128);
         // IPv6
