@@ -11,6 +11,8 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
+    Copyright (C) 2016-2025 Gerbera Contributors
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -28,16 +30,22 @@
 */
 
 /// \file timer.cc
-
+#define GRB_LOG_FAC GrbLogFacility::util
 #include "timer.h" // API
 
+#include "exceptions.h"
+#include "util/logger.h"
+
 void Timer::run()
 {
     log_debug("Starting Timer thread...");
     threadRunner = std::make_unique<StdThreadRunner>(
         "TimerThread", [](void* arg) {
             auto inst = static_cast<Timer*>(arg);
-            inst->threadProc();
+            if (inst)
+                inst->threadProc();
+            else
+                log_error("Timer thread without timer");
         },
         this);
 
@@ -125,6 +133,7 @@ void Timer::triggerWait()
         }
         notify();
     }
+    log_vdebug("triggerWait end - {} subscriber(s)", subscribers.size());
 }
 
 void Timer::notify()
@@ -175,7 +184,9 @@ std::chrono::milliseconds Timer::getNextNotifyTime() const
 
 void Timer::shutdown()
 {
+    log_debug("start");
     shutdownFlag = true;
     threadRunner->notifyAll();
     threadRunner->join();
+    log_debug("end");
 }
