@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -45,6 +45,9 @@ class Timer {
 public:
     enum class TimerParamType {
         IDAutoscan,
+#ifdef HAVE_JS
+        IDScript,
+#endif
 #ifdef ONLINE_SERVICES
         IDOnlineContent,
 #endif
