@@ -11,6 +11,8 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
+    Copyright (C) 2016-2025 Gerbera Contributors
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -28,11 +30,17 @@
 */
 
 /// \file tools.cc
-
+#define GRB_LOG_FAC GrbLogFacility::content
 #include "tools.h" // API
 
+#include "config/config.h"
+#include "contrib/md5.h"
+#include "util/logger.h"
+
+#include <algorithm>
 #include <numeric>
 #include <queue>
+#include <regex>
 #include <sstream>
 
 #ifdef __HAIKU__
@@ -45,8 +53,10 @@
 #include <uuid/uuid.h>
 #endif
 
-#include "config/config_manager.h"
-#include "contrib/md5.h"
+#ifdef HAVE_ICU
+#include <unicode/translit.h>
+#include <unicode/ustream.h>
+#endif
 
 static constexpr auto hexChars = "0123456789abcdef";
 
@@ -72,6 +82,31 @@ std::vector<std::string> splitString(std::string_view str, char sep, bool empty)
     return ret;
 }
 
+std::string camelCaseString(const std::string_view& str)
+{
+    std::string ret;
+
+    std::size_t pos = 0;
+    std::size_t end = 0;
+    while (end < str.size()) {
+        if (str.at(end) == '-') {
+            if (pos < end) {
+                ret.append(str.substr(pos, end - pos));
+            }
+            ++end;
+            if (end < str.size())
+                ret.push_back(::toupper(str.at(end)));
+            pos = end + 1;
+        }
+        ++end;
+    }
+
+    if (pos < end)
+        ret.append(str.substr(pos, end));
+
+    return ret;
+}
+
 void trimStringInPlace(std::string& str)
 {
     str.erase(str.begin(), std::find_if_not(str.begin(), str.end(), ::isspace));
@@ -105,20 +140,46 @@ std::string toUpper(std::string str)
     return str;
 }
 
-int stoiString(const std::string& str, int def, int base)
+std::int32_t stoiString(const std::string& str, std::int32_t def, std::int32_t base)
 {
     if (str.empty() || (str[0] == '-' && !std::isdigit(*str.substr(1).c_str())) || (str[0] != '-' && !std::isdigit(*str.c_str())))
         return def;
 
-    return std::stoi(str, nullptr, base);
+    try {
+        std::size_t pos;
+        return std::stoi(str, &pos, base);
+    } catch (const std::exception& ex) {
+        log_error("{} (input {})", ex.what(), str);
+    }
+    return def;
 }
 
-unsigned long stoulString(const std::string& str, int def, int base)
+std::int64_t stolString(const std::string& str, std::int64_t def, std::int64_t base)
 {
     if (str.empty() || (str[0] == '-' && !std::isdigit(*str.substr(1).c_str())) || (str[0] != '-' && !std::isdigit(*str.c_str())))
         return def;
 
-    return std::stoul(str, nullptr, base);
+    try {
+        std::size_t pos;
+        return std::stol(str, &pos, base);
+    } catch (const std::exception& ex) {
+        log_error("{} (input {})", ex.what(), str);
+    }
+    return def;
+}
+
+unsigned long stoulString(const std::string& str, unsigned long def, unsigned long base)
+{
+    if (str.empty() || (str[0] == '-' && !std::isdigit(*str.substr(1).c_str())) || (str[0] != '-' && !std::isdigit(*str.c_str())))
+        return def;
+
+    try {
+        std::size_t pos;
+        return std::stoul(str, &pos, base);
+    } catch (const std::exception& ex) {
+        log_error("{} (input {})", ex.what(), str);
+    }
+    return def;
 }
 
 void reduceString(std::string& str, char ch)
@@ -145,11 +206,22 @@ void replaceAllString(std::string& str, std::string_view from, std::string_view
     }
 }
 
-std::string renderWebUri(std::string_view ip, int port)
+std::string expandNumbersString(std::string str, std::size_t size)
 {
-    if (ip.find(':') != std::string_view::npos)
-        return fmt::format("[{}]:{}", ip, port);
-    return fmt::format("{}:{}", ip, port);
+    static const std::regex strRe("([0-9]+)");
+    std::smatch strMatch;
+    std::string result;
+    while (std::regex_search(str, strMatch, strRe)) {
+        std::string matchStr = strMatch[1].str();
+
+        if (!matchStr.empty()) {
+            auto matchInt = std::stoul(matchStr);
+            result += fmt::format("{0}{1:0{2}}", strMatch.prefix().str(), matchInt, matchStr.size() < size ? size : matchStr.size());
+            str = strMatch.suffix();
+        }
+    }
+    result += str; // append trailing chars
+    return result;
 }
 
 std::string httpRedirectTo(std::string_view addr, std::string_view page)
@@ -197,7 +269,7 @@ std::string hexMd5(const void* data, std::size_t length)
 
     md5_state_t ctx;
     md5_init(&ctx);
-    md5_append(&ctx, static_cast<unsigned char*>(const_cast<void*>(data)), length);
+    md5_append(&ctx, const_cast<unsigned char*>(static_cast<const unsigned char*>(data)), length);
     md5_finish(&ctx, reinterpret_cast<unsigned char*>(md5buf));
 
     return hexEncode(md5buf, 16);
@@ -235,143 +307,6 @@ std::string generateRandomId()
     return uuidString;
 }
 
-static constexpr auto hexCharS2 = "0123456789ABCDEF";
-
-std::string urlEscape(std::string_view str)
-{
-    std::ostringstream buf;
-    for (std::size_t i = 0; i < str.length();) {
-        auto c = str[i];
-        int cplen = 1;
-        if ((c & 0xf8) == 0xf0)
-            cplen = 4;
-        else if ((c & 0xf0) == 0xe0)
-            cplen = 3;
-        else if ((c & 0xe0) == 0xc0)
-            cplen = 2;
-        if ((i + cplen) > str.length())
-            cplen = 1;
-
-        if ((c >= '0' && c <= '9') || (c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || c == '_' || c == '-') {
-            buf << char(c);
-        } else {
-            int hi = c >> 4;
-            int lo = c & 15;
-            if (cplen > 1)
-                buf << str.substr(i, cplen);
-            else
-                buf << '%' << hexCharS2[hi] << hexCharS2[lo];
-        }
-        i += cplen;
-    }
-    return buf.str();
-}
-
-std::string urlUnescape(std::string_view str)
-{
-    auto data = str.data();
-    int len = str.length();
-    std::ostringstream buf;
-
-    int i = 0;
-    while (i < len) {
-        const char c = data[i++];
-        if (c == '%') {
-            if (i + 2 > len)
-                break; // avoid buffer overrun
-            char chi = data[i++];
-            char clo = data[i++];
-
-            auto pos = std::strchr(hexCharS2, chi);
-            int hi = pos ? pos - hexCharS2 : 0;
-
-            pos = std::strchr(hexCharS2, clo);
-            int lo = pos ? pos - hexCharS2 : 0;
-
-            int ascii = (hi << 4) | lo;
-            buf << char(ascii);
-        } else if (c == '+') {
-            buf << ' ';
-        } else {
-            buf << c;
-        }
-    }
-    return buf.str();
-}
-
-static std::string dictEncode(const std::map<std::string, std::string>& dict, char sep1, char sep2)
-{
-    std::ostringstream buf;
-    for (auto it = dict.begin(); it != dict.end(); ++it) {
-        if (it != dict.begin())
-            buf << sep1;
-        buf << urlEscape(it->first) << sep2
-            << urlEscape(it->second);
-    }
-    return buf.str();
-}
-
-std::string dictEncode(const std::map<std::string, std::string>& dict)
-{
-    return dictEncode(dict, '&', '=');
-}
-
-std::string dictEncodeSimple(const std::map<std::string, std::string>& dict)
-{
-    return dictEncode(dict, '/', '/');
-}
-
-std::map<std::string, std::string> dictDecode(std::string_view url, bool unEscape)
-{
-    std::map<std::string, std::string> dict;
-    const char* data = url.data();
-    const char* dataEnd = data + url.length();
-    while (data < dataEnd) {
-        const char* ampPos = std::strchr(data, '&');
-        if (!ampPos) {
-            ampPos = dataEnd;
-        }
-        const char* eqPos = std::strchr(data, '=');
-        if (eqPos && eqPos < ampPos) {
-            auto key = std::string_view(data, eqPos - data);
-            auto value = std::string_view(eqPos + 1, ampPos - eqPos - 1);
-            if (unEscape) {
-                dict.try_emplace(urlUnescape(key), urlUnescape(value));
-            } else {
-                dict.emplace(key, value);
-            }
-        }
-        data = ampPos + 1;
-    }
-    return dict;
-}
-
-std::map<std::string, std::string> pathToMap(std::string_view url)
-{
-    std::map<std::string, std::string> out;
-    std::size_t pos;
-    std::size_t lastPos = 0;
-    std::size_t size = url.size();
-    do {
-        pos = url.find('/', lastPos);
-        if (pos == std::string_view::npos)
-            pos = size;
-
-        std::string key = urlUnescape(url.substr(lastPos, pos - lastPos));
-        lastPos = pos == size ? size : pos + 1;
-        pos = url.find('/', lastPos);
-        if (pos == std::string::npos)
-            pos = size;
-
-        std::string value = urlUnescape(url.substr(lastPos, pos - lastPos));
-        lastPos = pos + 1;
-
-        out.emplace(key, value);
-    } while (lastPos < size);
-
-    return out;
-}
-
 std::string mimeTypesToCsv(const std::vector<std::string>& mimeTypes)
 {
     return mimeTypes.empty() ? "" : fmt::format("http-get:*:{}:*", fmt::join(mimeTypes, ":*,http-get:*:"));
@@ -403,36 +338,6 @@ std::string_view getProtocol(std::string_view protocolInfo)
     return (pos == std::string_view::npos || pos == 0) ? PROTOCOL : protocolInfo.substr(0, pos);
 }
 
-std::string millisecondsToHMSF(int milliseconds)
-{
-    auto ms = milliseconds % 1000;
-    milliseconds /= 1000;
-
-    auto s = milliseconds % 60;
-    milliseconds /= 60;
-
-    auto m = milliseconds % 60;
-    auto h = milliseconds / 60;
-
-    return fmt::format("{:01}:{:02}:{:02}.{:03}", h, m, s, ms);
-}
-
-int HMSFToMilliseconds(std::string_view time)
-{
-    if (time.empty()) {
-        log_warning("Could not convert time representation to seconds!");
-        return 0;
-    }
-
-    int hours = 0;
-    int minutes = 0;
-    int seconds = 0;
-    int ms = 0;
-    sscanf(time.data(), "%d:%d:%d.%d", &hours, &minutes, &seconds, &ms);
-
-    return ((hours * 3600) + (minutes * 60) + seconds) * 1000 + ms;
-}
-
 std::string escape(std::string_view string, char escapeChar, char toEscape)
 {
     std::ostringstream buf;
@@ -463,7 +368,7 @@ std::string escape(std::string_view string, char escapeChar, char toEscape)
 
         if (next == std::string::npos)
             next = len;
-        auto cpLen = int(next - last);
+        auto cpLen = static_cast<int>(next - last);
         if (cpLen > 0) {
             buf.write(&string[last], cpLen);
         }
@@ -498,27 +403,6 @@ std::string getValueOrDefault(const std::map<std::string, std::string>& m, const
     return getValueOrDefault<std::string, std::string>(m, key, defval);
 }
 
-std::chrono::seconds currentTime()
-{
-    return std::chrono::duration_cast<std::chrono::seconds>(std::chrono::system_clock::now().time_since_epoch());
-}
-
-std::chrono::milliseconds currentTimeMS()
-{
-    return std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::system_clock::now().time_since_epoch());
-}
-
-std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds ms)
-{
-    auto now = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::system_clock::now().time_since_epoch());
-    return now - ms;
-}
-
-std::chrono::milliseconds getDeltaMillis(std::chrono::milliseconds first, std::chrono::milliseconds second)
-{
-    return second - first;
-}
-
 std::vector<std::string> populateCommandLine(const std::string& line,
     const std::string& in,
     const std::string& out,
@@ -559,15 +443,13 @@ ssize_t getValidUTF8CutPosition(std::string_view str, ssize_t cutpos)
     ssize_t pos = -1;
     auto len = str.length();
 
-    if ((len == 0) || (cutpos > ssize_t(len)))
+    if ((len == 0) || (cutpos > static_cast<ssize_t>(len)))
         return pos;
 
-#if 0
-    printf("Character at cut position: %0x\n", char(str.at(cutpos)));
-    printf("Character at cut-1 position: %0x\n", char(str.at(cutpos - 1)));
-    printf("Character at cut-2 position: %0x\n", char(str.at(cutpos - 2)));
-    printf("Character at cut-3 position: %0x\n", char(str.at(cutpos - 3)));
-#endif
+    log_vdebug("Character at cut position: {:0x}", char(str.at(cutpos)));
+    log_vdebug("Character at cut-1 position: {:0x}", char(str.at(cutpos - 1)));
+    log_vdebug("Character at cut-2 position: {:0x}", char(str.at(cutpos - 2)));
+    log_vdebug("Character at cut-3 position: {:0x}", char(str.at(cutpos - 3)));
 
     // > 0x7f, we are dealing with a non-ascii character
     if (str.at(cutpos) & 0x80) {
@@ -585,3 +467,54 @@ ssize_t getValidUTF8CutPosition(std::string_view str, ssize_t cutpos)
 
     return pos;
 }
+
+static constexpr std::string_view ellipse("...");
+
+std::string limitString(std::size_t stringLimit, const std::string& s)
+{
+    // Do nothing if string is already short enough
+    if (s.length() <= stringLimit)
+        return s;
+
+    ssize_t cutPosition = getValidUTF8CutPosition(s, stringLimit - ellipse.size());
+    return fmt::format("{}{}", s.substr(0, cutPosition), ellipse);
+}
+
+std::string transliterate(const std::string& input)
+{
+#ifdef HAVE_ICU
+    // Thanks to https://github.com/sangohan/vimix/blob/8a36a94e732df0bab0dd69891c93dd3d8e9db6ec/BaseToolkit.cpp#L82-L113
+    // and https://unicode-org.github.io/icu/userguide/transforms/general/#icu-transliterators
+    // icu::Transliterator is slow, we keep a cache of already
+    // transliterated texts to be faster during repeated calls
+    static std::map<std::string, std::string> translitCache;
+    auto existingentry = translitCache.find(input);
+
+    if (existingentry == translitCache.end()) {
+
+        auto unicodeString = icu::UnicodeString::fromUTF8(input);
+
+        UErrorCode status = U_ZERO_ERROR;
+        for (auto&& translit : {
+                 "any-NFKD ; [:Nonspacing Mark:] Remove; NFKC; Latin",
+                 "any-NFKD ; [:Nonspacing Mark:] Remove; [@!#$*%~] Remove; NFKC",
+             }) {
+            icu::Transliterator* trans = icu::Transliterator::createInstance(
+                translit, UTRANS_FORWARD, status);
+            trans->transliterate(unicodeString);
+            delete trans;
+        }
+
+        std::ostringstream result;
+        result << unicodeString;
+
+        // remember for future
+        translitCache[input] = result.str();
+    }
+
+    // return remembered transliterated text
+    return translitCache.at(input);
+#else
+    return input;
+#endif
+}
