@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -73,12 +73,15 @@ constexpr bool startswith(std::string_view str, std::string_view prefix)
 constexpr bool endswith(std::string_view str, std::string_view suffix)
 {
 #if __cpp_lib_starts_ends_with
-    return str.ends_with(check);
+    return str.ends_with(suffix);
 #else
     return str.size() >= suffix.size() && str.compare(str.size() - suffix.size(), suffix.size(), suffix) == 0;
 #endif
 }
 
+/// \brief removes "-" and make following character uppercase
+std::string camelCaseString(const std::string_view& str);
+
 /// \brief returns uppercase of str
 std::string toUpper(std::string str);
 
@@ -94,13 +97,16 @@ std::int64_t stolString(const std::string& str, std::int64_t def = 0, std::int64
 /// \brief convert string to unsigned long
 unsigned long stoulString(const std::string& str, unsigned long def = 0, unsigned long base = 10);
 
-/// \brief  Used to replace potential multiple following //../ with single /
+/// \brief Used to replace potential multiple following //../ with single /
 void reduceString(std::string& str, char ch);
 
-/// \brief  Used to replace parts of string with other value
+/// \brief Used to replace parts of string with other value
 void replaceString(std::string& str, std::string_view from, std::string_view to);
 void replaceAllString(std::string& str, std::string_view from, std::string_view to);
 
+/// \brief Used to expand number to fixed length for filesystem "natural" sorting
+std::string expandNumbersString(std::string str, std::size_t size = 16);
+
 /// \brief Render HTML that is doing a redirect to the given ip, port and html page.
 /// \param addr IP address as string.
 /// \param page HTML document to redirect to.
@@ -200,7 +206,14 @@ std::vector<std::string> populateCommandLine(const std::string& line,
     const std::string& title = "");
 
 /// \brief Calculates a position where it is safe to cut an UTF-8 string.
-/// \return Caclulated position or -1 in case of an error.
+/// \return Calculated position or -1 in case of an error.
 ssize_t getValidUTF8CutPosition(std::string_view str, ssize_t cutpos);
 
+/// \brief reduce size of string at length
+std::string limitString(std::size_t stringLimit, const std::string& s);
+
+/// \brief transliterate a string to ascii for display on restricted devices
+/// \return transliterated string
+std::string transliterate(const std::string& input);
+
 #endif // __TOOLS_H__
