@@ -11,7 +11,7 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -40,9 +40,10 @@
 #include "util/logger.h"
 
 #include <sstream>
+#include <utility>
 
-URL::URL(const std::string& url, CURL* curlHandle)
-    : url(url)
+URL::URL(std::string url, CURL* curlHandle)
+    : url(std::move(url))
     , curlHandle(curlHandle)
 {
     if (!curlHandle) {
