@@ -4,7 +4,7 @@
 
     url_utils.h - this file is part of Gerbera.
 
-    Copyright (C) 2022-2024 Gerbera Contributors
+    Copyright (C) 2022-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -29,6 +29,7 @@
 #include <utility>
 #include <vector>
 
+// URL FORMATTING CONSTANTS
 constexpr auto URL_PARAM_SEPARATOR = std::string_view("/");
 
 namespace URLUtils {
@@ -46,6 +47,7 @@ namespace URLUtils {
 /// parameters = "object_id=12345&transcode=wav"
 std::pair<std::string_view, std::string_view> splitUrl(std::string_view url, char separator);
 std::string_view getQuery(std::string_view url);
+std::string_view getFile(std::string_view url);
 std::string joinUrl(const std::vector<std::string>& components, bool addToEnd = false, std::string_view separator = URL_PARAM_SEPARATOR);
 std::map<std::string, std::string> parseParameters(std::string_view filename, std::string_view baseLink);
 
