@@ -36,12 +36,10 @@
 
 #include "content/content.h"
 #include "exceptions.h"
-#include "util/tools.h"
-#include "util/xml_to_json.h"
 
 const std::string_view Web::EditSave::PAGE = "edit_save";
 
-bool Web::EditSave::processPageAction(pugi::xml_node& element, const std::string& action)
+bool Web::EditSave::processPageAction(Json::Value& element, const std::string& action)
 {
     std::string objID = param("object_id");
     if (objID.empty())
