@@ -42,7 +42,7 @@ public:
     {
         std::shared_ptr<ConfigDefinition> definition = std::make_shared<ConfigDefinition>();
         definition->init(definition);
-        subject = new ConfigGenerator(definition, false);
+        subject = new ConfigGenerator(definition, GERBERA_TEST, false);
         subject->init();
         homePath = "/tmp";
         configDir = ".config/gerbera";
@@ -339,7 +339,7 @@ public:
     {
         std::shared_ptr<ConfigDefinition> definition = std::make_shared<ConfigDefinition>();
         definition->init(definition);
-        subject = new ConfigGenerator(definition, true);
+        subject = new ConfigGenerator(definition, GERBERA_TEST, true);
         subject->init();
         homePath = "/tmp";
         configDir = ".config/gerbera";
@@ -375,6 +375,9 @@ TEST_F(ExampleConfigGeneratorTest, GeneratesFullConfigXmlWithExiv2AllDefinitions
     std::string mockXml = mockConfigXml("fixtures/mock-example-exiv2-all.xml");
 #endif
     std::string result = subject->generate(homePath, configDir, prefixDir, magicFile);
+#ifdef GERBERA_RELEASE
+    replaceAllString(mockXml, "https://docs.gerbera.io/en/latest/", "https://docs.gerbera.io/en/stable/");
+#endif
 
     // remove UUID, for simple compare...TODO: mock UUID?
     std::regex reg("<udn>uuid:[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{12}</udn>");
@@ -391,6 +394,9 @@ TEST_F(ExampleConfigGeneratorTest, GeneratesFullConfigXmlWithAllDefinitions)
     std::string mockXml = mockConfigXml("fixtures/mock-example-all-os.xml");
 #else
     std::string mockXml = mockConfigXml("fixtures/mock-example-all.xml");
+#endif
+#ifdef GERBERA_RELEASE
+    replaceAllString(mockXml, "https://docs.gerbera.io/en/latest/", "https://docs.gerbera.io/en/stable/");
 #endif
     std::string result = subject->generate(homePath, configDir, prefixDir, magicFile);
 
@@ -406,6 +412,9 @@ TEST_F(ExampleConfigGeneratorTest, GeneratesFullConfigXmlWithAllDefinitions)
 TEST_F(ExampleConfigGeneratorTest, GeneratesConfigXmlWithDefaultDefinitions)
 {
     std::string mockXml = mockConfigXml("fixtures/mock-example-minimal.xml");
+#ifdef GERBERA_RELEASE
+    replaceAllString(mockXml, "https://docs.gerbera.io/en/latest/", "https://docs.gerbera.io/en/stable/");
+#endif
 
     std::string result = subject->generate(homePath, configDir, prefixDir, magicFile);
 
