@@ -4,7 +4,7 @@
 
     test_searchhandler.cc - this file is part of Gerbera.
 
-    Copyright (C) 2018-2024 Gerbera Contributors
+    Copyright (C) 2018-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -205,6 +205,16 @@ TEST(SearchLexer, MultipleTokens)
     };
     EXPECT_TRUE(executeSearchLexerTest(input, expectedTokens));
 
+    input = R"(upnp:contentClass derivedfrom "object.item.audioItem")";
+    expectedTokens = {
+        { "upnp:contentClass", TokenType::PROPERTY },
+        { "derivedfrom", TokenType::STRINGOP },
+        { "\"", TokenType::DQUOTE },
+        { "object.item.audioItem", TokenType::ESCAPEDSTRING },
+        { "\"", TokenType::DQUOTE },
+    };
+    EXPECT_TRUE(executeSearchLexerTest(input, expectedTokens));
+
     input = R"(upnp:class derivedfrom "object.item.audioItem" and upnp:artist="King Krule")";
     expectedTokens = {
         { "upnp:class", TokenType::PROPERTY },
