@@ -4,7 +4,7 @@
 
     test_upnp_xml.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -26,7 +26,9 @@
 #include "common.h"
 #include "config/result/client_config.h"
 #include "config/result/transcoding.h"
+#include "config/config_definition.h"
 #include "config/config_setup.h"
+#include "context.h"
 #include "metadata/metadata_handler.h"
 #include "upnp/client_manager.h"
 #include "upnp/xml_builder.h"
@@ -58,7 +60,10 @@ public:
 
         database = std::make_shared<DatabaseMock>(config);
         converterManager = std::make_shared<ConverterManager>(config);
-        context = std::make_shared<Context>(config, nullptr, nullptr, database, nullptr, converterManager);
+
+        std::shared_ptr<ConfigDefinition> definition = std::make_shared<ConfigDefinition>();
+        definition->init(definition);
+        context = std::make_shared<Context>(definition, config, nullptr, nullptr, database, nullptr, converterManager);
 
         std::string virtualDir = "http://server";
         std::string presentationURl = "http://someurl/";
@@ -115,11 +120,12 @@ TEST_F(UpnpXmlTest, RenderObjectContainer)
     expectedXml << "<upnp:date>2001-01-01</upnp:date>\n";
     expectedXml << "<upnp:orchestra>Orchestra</upnp:orchestra>\n";
     expectedXml << "<upnp:albumArtURI>http://server/media/object_id/1/res_id/0/ext/file.jpg</upnp:albumArtURI>\n";
+    expectedXml << "<res id=\"1.0\" protocolInfo=\"http-get:*:jpg:DLNA.ORG_OP=01;DLNA.ORG_CI=0\">http://server/media/object_id/1/res_id/0/ext/file.jpg</res>\n";
     expectedXml << "</container>\n";
     expectedXml << "</DIDL-Lite>\n";
 
     // act
-    subject->renderObject(obj, std::string::npos, root);
+    subject->renderObject(obj, { "*" }, std::string::npos, root);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
@@ -161,7 +167,7 @@ TEST_F(UpnpXmlTest, RenderObjectItem)
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, root);
+    subject->renderObject(obj, { "*" }, std::string::npos, root);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
@@ -208,7 +214,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithEscapes)
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, root, quirks);
+    subject->renderObject(obj, { "*" }, std::string::npos, root, quirks);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
@@ -255,7 +261,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithStrictXmlQuirks)
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, root, quirks);
+    subject->renderObject(obj, { "*" }, std::string::npos, root, quirks);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "", pugi::format_no_escapes);
@@ -319,10 +325,10 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
     expectedXml << "<upnp:originalTrackNumber>7</upnp:originalTrackNumber>\n";
     expectedXml << "<upnp:albumArtURI xmlns:dlna=\"urn:schemas-dlna-org:metadata-1-0\" dlna:profileID=\"JPEG_TN\">http://server/media/object_id/42/res_id/3/ext/file.jpg</upnp:albumArtURI>\n";
     expectedXml << "<sec:CaptionInfoEx protocolInfo=\"http-get:*:text/srt:*\" sec:type=\"srt\">http://server/media/object_id/42/res_id/1/type/srt/ext/file.srt</sec:CaptionInfoEx>\n";
-    expectedXml << "<res size=\"4711\" duration=\"123456\" bitrate=\"16044\" nrAudioChannels=\"2\" protocolInfo=\"http-get:*:audio/mpeg:DLNA.ORG_PN=MP3;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=01700000000000000000000000000000\">http://server/media/object_id/42/res_id/0/group/default/ext/file.mp3</res>\n";
-    expectedXml << "<res protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\">http://server/media/object_id/42/res_id/1/type/srt/ext/file.srt</res>\n";
-    expectedXml << "<res protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\" dc:language=\"fr\">http://server/media/object_id/42/res_id/2/type/srt/ext/file.fr.srt</res>\n";
-    expectedXml << "<res resolution=\"200x200\" protocolInfo=\"http-get:*:image/jpeg:DLNA.ORG_PN=JPEG_TN;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00800000000000000000000000000000\">http://server/media/object_id/42/res_id/3/ext/file.jpg</res>\n";
+    expectedXml << "<res id=\"42.0\" size=\"4711\" duration=\"123456\" bitrate=\"16044\" nrAudioChannels=\"2\" protocolInfo=\"http-get:*:audio/mpeg:DLNA.ORG_PN=MP3;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=01700000000000000000000000000000\">http://server/media/object_id/42/res_id/0/group/default/ext/file.mp3</res>\n";
+    expectedXml << "<res id=\"42.1\" protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\">http://server/media/object_id/42/res_id/1/type/srt/ext/file.srt</res>\n";
+    expectedXml << "<res id=\"42.2\" protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\" dc:language=\"fr\">http://server/media/object_id/42/res_id/2/type/srt/ext/file.fr.srt</res>\n";
+    expectedXml << "<res id=\"42.3\" resolution=\"200x200\" protocolInfo=\"http-get:*:image/jpeg:DLNA.ORG_PN=JPEG_TN;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00800000000000000000000000000000\">http://server/media/object_id/42/res_id/3/ext/file.jpg</res>\n";
     expectedXml << "</item>\n";
     expectedXml << "</DIDL-Lite>\n";
 
@@ -332,7 +338,7 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
     // act
-    subject->renderObject(obj, std::string::npos, root);
+    subject->renderObject(obj, { "*" }, std::string::npos, root);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
