@@ -4,7 +4,7 @@
 
     test_sql_generators.cc - this file is part of Gerbera.
 
-    Copyright (C) 2021-2024 Gerbera Contributors
+    Copyright (C) 2021-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -24,6 +24,8 @@
 /// \file test_sql_generators.cc
 #include "database/sql_database.h"
 
+#include "sqlite_config_fake.h"
+
 #include <fmt/core.h>
 #include <gtest/gtest.h>
 
@@ -95,6 +97,7 @@ class DatabaseTest : public ::testing::Test {
 public:
     void SetUp() override
     {
+        config = std::make_shared<SqliteConfigFake>();
         database = std::make_shared<TestDatabase>(config, mime, converterManager);
     }
 
@@ -118,10 +121,12 @@ TEST_F(DatabaseTest, BasicFormattingTest)
 
 TEST_F(DatabaseTest, UpdateTest)
 {
-    database->updateRow(
+    database->execOnly("UPDATE [Table] SET [a] = 4, [b] = 101 WHERE [id] = 1234");
+    /*
         "Table",
         { ColumnUpdate(database->identifier("a"), "4"), ColumnUpdate(database->identifier("b"), "101") },
-        "id", 1234);
+        "id", 1234;
+    */
     EXPECT_EQ(database->lastStatement, "UPDATE [Table] SET [a] = 4, [b] = 101 WHERE [id] = 1234");
 }
 
