@@ -3,7 +3,7 @@
 
     common_script_mock.h - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -40,6 +40,7 @@ public:
     virtual duk_ret_t print2(std::string mode, std::string text) = 0;
     virtual duk_ret_t addContainerTree(std::vector<std::string> tree) = 0;
     virtual duk_ret_t createContainerChain(std::vector<std::string> chain) = 0;
+    virtual duk_ret_t mapGenre(std::string genre) = 0;
     virtual duk_ret_t getLastPath(std::string path) = 0;
     virtual duk_ret_t getLastPath2(std::string path, int length) = 0;
     virtual duk_ret_t readln(std::string line) = 0;
@@ -60,6 +61,7 @@ public:
     MOCK_METHOD2(print2, duk_ret_t(std::string mode, std::string text));
     MOCK_METHOD1(addContainerTree, duk_ret_t(std::vector<std::string> tree));
     MOCK_METHOD1(createContainerChain, duk_ret_t(std::vector<std::string> chain));
+    MOCK_METHOD1(mapGenre, duk_ret_t(std::string genre));
     MOCK_METHOD1(getLastPath, duk_ret_t(std::string path));
     MOCK_METHOD2(getLastPath2, duk_ret_t(std::string path, int length));
     MOCK_METHOD1(readln, duk_ret_t(std::string line));
@@ -72,5 +74,5 @@ public:
     MOCK_METHOD2(getRootPath, duk_ret_t(std::string objScriptPath, std::string location));
     MOCK_METHOD3(abcBox, duk_ret_t(std::string inputValue, int boxType, std::string divChar));
 };
-#endif //HAVE_JS
-#endif //GERBERA_COMMON_SCRIPT_MOCK_H
+#endif // HAVE_JS
+#endif // GERBERA_COMMON_SCRIPT_MOCK_H
