@@ -4,7 +4,7 @@
 
     duk_helper.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -24,6 +24,8 @@
 
 #include "duk_helper.h"
 
+#include "content/scripting/duk_compat.h"
+
 #include <duktape.h>
 #include <fmt/format.h>
 #if FMT_VERSION >= 100202
@@ -63,7 +65,6 @@ std::vector<std::string> DukTestHelper::containerToPath(duk_context* ctx, duk_id
                 duk_pop(ctx); // item
                 break;
             }
-            //duk_to_object(ctx, -1);
             duk_get_prop_string(ctx, -1, "title");
             if (!duk_is_null_or_undefined(ctx, -1)) {
                 std::string val = duk_to_string(ctx, -1);
@@ -193,10 +194,6 @@ void DukTestHelper::createObject(duk_context* ctx, const std::map<std::string, s
 
 void DukTestHelper::printError(duk_context* ctx, const std::string& message, const std::string& item)
 {
-#if DUK_VERSION > 20399
     std::cerr << message << item << ": " << duk_safe_to_stacktrace(ctx, -1) << std::endl;
-#else
-    std::cerr << message << item << ": " << duk_safe_to_string(ctx, -1) << std::endl;
-#endif
 }
-#endif //HAVE_JS
+#endif // HAVE_JS
