@@ -22,10 +22,7 @@
 */
 #ifdef HAVE_JS
 
-#include "cds/cds_objects.h"
-#include "config/result/autoscan.h"
 #include "content/scripting/script_names.h"
-#include "metadata/metadata_enums.h"
 #include "util/grb_fs.h"
 #include "util/tools.h"
 
@@ -46,19 +43,6 @@ void ScriptTestFixture::SetUp()
     ctx = duk_create_heap(nullptr, nullptr, nullptr, nullptr, nullptr);
 
     loadCommon(ctx);
-
-    if (functionName.empty()) {
-        fs::path scriptFile = fs::path(SCRIPTS_DIR) / "js" / scriptName;
-        std::string scriptContent = GrbFile(scriptFile).readTextFile();
-        duk_push_thread_stash(ctx, ctx);
-        duk_push_string(ctx, scriptFile.c_str());
-        if (duk_pcompile_lstring_filename(ctx, 0, scriptContent.c_str(), scriptContent.length()) != DUK_EXEC_SUCCESS) {
-            DukTestHelper::printError(ctx, "Failed to load script ", scriptFile);
-            return;
-        }
-        duk_put_global_string(ctx, "script_under_test");
-        duk_pop(ctx);
-    }
 }
 
 void ScriptTestFixture::TearDown()
@@ -68,40 +52,24 @@ void ScriptTestFixture::TearDown()
 
 void ScriptTestFixture::loadCommon(duk_context* ctx) const
 {
-    if (scriptName != "common.js" && functionName.empty()) {
-        fs::path commonScript = fs::path(SCRIPTS_DIR) / "js" / "common.js";
-        std::string script = GrbFile(commonScript).readTextFile();
-        duk_push_string(ctx, commonScript.c_str());
-
-        if (duk_pcompile_lstring_filename(ctx, 0, script.c_str(), script.length())) {
-            DukTestHelper::printError(ctx, "Failed to load script ", commonScript);
-            return;
-        }
-        if (duk_pcall(ctx, 0) != DUK_EXEC_SUCCESS) {
-            DukTestHelper::printError(ctx, "Failed to execute script ", commonScript);
-            return;
-        }
-        duk_pop(ctx); // commonScript
-    } else if (scriptName != "common.js") {
-        auto dirIterator = fs::directory_iterator(fs::path(SCRIPTS_DIR) / "js");
-        for (auto&& dirEntry : dirIterator) {
-            auto&& entryPath = dirEntry.path();
-            if (entryPath.extension() == ".js") {
-                try {
-                    std::string script = GrbFile(entryPath).readTextFile();
-                    duk_push_string(ctx, entryPath.c_str());
-                    if (duk_pcompile_lstring_filename(ctx, 0, script.c_str(), script.length())) {
-                        DukTestHelper::printError(ctx, "Failed to load script ", entryPath);
-                        return;
-                    }
-                    if (duk_pcall(ctx, 0) != DUK_EXEC_SUCCESS) {
-                        DukTestHelper::printError(ctx, "Failed to execute script ", entryPath);
-                        return;
-                    }
-                    duk_pop(ctx); // entryPath
-                } catch (const std::runtime_error& e) {
-                    std::cerr << "Unable to load  " << entryPath << ": " << e.what() << std::endl;
+    auto dirIterator = fs::directory_iterator(fs::path(SCRIPTS_DIR) / "js");
+    for (auto&& dirEntry : dirIterator) {
+        auto&& entryPath = dirEntry.path();
+        if (entryPath.extension() == ".js") {
+            try {
+                std::string script = GrbFile(entryPath).readTextFile();
+                duk_push_string(ctx, entryPath.c_str());
+                if (duk_pcompile_lstring_filename(ctx, 0, script.c_str(), script.length())) {
+                    DukTestHelper::printError(ctx, "Failed to load script ", entryPath);
+                    return;
                 }
+                if (duk_pcall(ctx, 0) != DUK_EXEC_SUCCESS) {
+                    DukTestHelper::printError(ctx, "Failed to execute script ", entryPath);
+                    return;
+                }
+                duk_pop(ctx); // entryPath
+            } catch (const std::runtime_error& e) {
+                std::cerr << "Unable to load  " << entryPath << ": " << e.what() << std::endl;
             }
         }
     }
@@ -169,98 +137,6 @@ void ScriptTestFixture::dukMockItem(
     }
 }
 
-duk_ret_t ScriptTestFixture::dukMockItem(
-    duk_context* ctx,
-    const std::string& mimetype,
-    const std::string& upnpClass,
-    const std::string& id,
-    int theora,
-    const std::string& title,
-    const std::vector<std::pair<std::string, std::string>>& meta,
-    const std::map<std::string, std::string>& aux,
-    const std::map<std::string, std::string>& res,
-    const std::string& location,
-    int onlineService)
-{
-    duk_push_sprintf(ctx, "%s", AutoscanDirectory::ContainerTypesDefaults.at(AutoscanMediaMode::Audio).c_str());
-    duk_put_global_string(ctx, "grb_container_type_audio");
-    duk_push_sprintf(ctx, "%s", AutoscanDirectory::ContainerTypesDefaults.at(AutoscanMediaMode::Image).c_str());
-    duk_put_global_string(ctx, "grb_container_type_image");
-    duk_push_sprintf(ctx, "%s", AutoscanDirectory::ContainerTypesDefaults.at(AutoscanMediaMode::Video).c_str());
-    duk_put_global_string(ctx, "grb_container_type_video");
-
-    const std::string objectName = "orig";
-    duk_idx_t origIdx = duk_push_object(ctx);
-    duk_push_string(ctx, mimetype.c_str());
-    duk_put_prop_string(ctx, origIdx, "mimetype");
-    duk_push_string(ctx, upnpClass.c_str());
-    duk_put_prop_string(ctx, origIdx, "upnpclass");
-    duk_push_string(ctx, id.c_str());
-    duk_put_prop_string(ctx, origIdx, "id");
-    duk_push_string(ctx, title.c_str());
-    duk_put_prop_string(ctx, origIdx, "title");
-    duk_push_string(ctx, location.c_str());
-    duk_put_prop_string(ctx, origIdx, "location");
-    duk_push_int(ctx, onlineService);
-    duk_put_prop_string(ctx, origIdx, "onlineservice");
-    duk_push_int(ctx, theora);
-    duk_put_prop_string(ctx, origIdx, "theora");
-
-    std::map<std::string, std::vector<std::string>> metaGroups;
-    for (auto&& [mkey, mvalue] : meta) {
-        if (metaGroups.find(mkey) == metaGroups.end()) {
-            metaGroups[mkey] = std::vector<std::string>();
-        }
-        metaGroups[mkey].push_back(mvalue);
-    }
-
-    // obj.meta
-    duk_idx_t metaIdx = duk_push_object(ctx);
-    for (auto&& [key, array] : metaGroups) {
-        duk_push_string(ctx, fmt::format("{}", fmt::join(array, "/")).c_str());
-        duk_put_prop_string(ctx, metaIdx, key.c_str());
-    }
-    duk_put_prop_string(ctx, origIdx, "meta");
-
-    metaIdx = duk_push_object(ctx);
-    // obj.metaData
-    for (auto&& [key, array] : metaGroups) {
-        auto dukArray = duk_push_array(ctx);
-        for (std::size_t i = 0; i < array.size(); i++) {
-            duk_push_string(ctx, array[i].c_str());
-            duk_put_prop_index(ctx, dukArray, i);
-        }
-        duk_put_prop_string(ctx, metaIdx, key.c_str());
-    }
-    duk_put_prop_string(ctx, origIdx, "metaData");
-
-    // obj.res
-    duk_idx_t resIdx = duk_push_object(ctx);
-    duk_push_string(ctx, fmt::to_string(res.size()).c_str());
-    duk_put_prop_string(ctx, resIdx, "count");
-    for (auto const& val : res) {
-        duk_push_string(ctx, val.second.c_str());
-        duk_put_prop_string(ctx, resIdx, val.first.c_str());
-    }
-    duk_put_prop_string(ctx, origIdx, "res");
-
-    // obj.aux
-    if (!aux.empty()) {
-        duk_idx_t auxIdx = duk_push_object(ctx);
-        for (auto const& val : aux) {
-            duk_push_string(ctx, val.second.c_str());
-            duk_put_prop_string(ctx, auxIdx, val.first.c_str());
-        }
-        duk_put_prop_string(ctx, origIdx, "aux");
-    }
-    duk_put_global_string(ctx, objectName.c_str());
-
-    // TODO: parameterize?
-    duk_push_string(ctx, "object/script/path");
-    duk_put_global_string(ctx, "object_script_path");
-    return 0;
-}
-
 int ScriptTestFixture::readLineCnt = 0;
 std::vector<std::string> ScriptTestFixture::lines;
 void ScriptTestFixture::mockPlaylistFile(const std::string& mockFile)
@@ -274,7 +150,10 @@ void ScriptTestFixture::mockPlaylistFile(const std::string& mockFile)
 
 void ScriptTestFixture::dukMockPlaylist(
     duk_context* ctx,
-    const std::map<std::string, std::string>& props)
+    const std::map<std::string, std::string>& props,
+    const std::vector<std::pair<std::string, std::string>>& meta,
+    const std::map<std::string, std::string>& aux,
+    const std::map<std::string, std::string>& res)
 {
     duk_push_object(ctx);
     for (auto&& [name, value] : props) {
@@ -283,62 +162,12 @@ void ScriptTestFixture::dukMockPlaylist(
     }
 }
 
-duk_ret_t ScriptTestFixture::dukMockPlaylist(
-    duk_context* ctx,
-    const std::string& title,
-    const std::string& location,
-    const std::string& mimetype)
-{
-    duk_push_object(ctx);
-    duk_push_string(ctx, location.c_str());
-    duk_put_prop_string(ctx, -2, "location");
-    duk_push_string(ctx, mimetype.c_str());
-    duk_put_prop_string(ctx, -2, "mimetype");
-    duk_push_string(ctx, title.c_str());
-    duk_put_prop_string(ctx, -2, "title");
-    duk_put_global_string(ctx, objectName.c_str());
-    return 0;
-}
-
-duk_ret_t ScriptTestFixture::dukMockMetafile(
-    duk_context* ctx,
-    const std::string& location,
-    const std::string& fileName)
-{
-    duk_push_object(ctx);
-    duk_push_string(ctx, location.c_str());
-    duk_put_prop_string(ctx, -2, "location");
-    duk_push_string(ctx, fmt::to_string(10).c_str());
-    duk_put_prop_string(ctx, -2, "trackNumber");
-    duk_push_string(ctx, fmt::to_string(0).c_str());
-    duk_put_prop_string(ctx, -2, "partNumber");
-    // setting metadata
-    {
-        duk_push_object(ctx);
-        auto dukArray = duk_push_array(ctx);
-        duk_push_string(ctx, fmt::to_string(10).c_str());
-        duk_put_prop_index(ctx, dukArray, 0);
-        duk_put_prop_string(ctx, -2, MetaEnumMapper::getMetaFieldName(MetadataFields::M_TRACKNUMBER).c_str());
-        dukArray = duk_push_array(ctx);
-        duk_push_string(ctx, fmt::to_string(0).c_str());
-        duk_put_prop_index(ctx, dukArray, 0);
-        duk_put_prop_string(ctx, -2, MetaEnumMapper::getMetaFieldName(MetadataFields::M_PARTNUMBER).c_str());
-        dukArray = duk_push_array(ctx);
-        duk_push_string(ctx, "done");
-        duk_put_prop_index(ctx, dukArray, 0);
-        duk_put_prop_string(ctx, -2, "upnp:none");
-        duk_put_prop_string(ctx, -2, "metaData");
-    }
-    duk_put_global_string(ctx, objectName.c_str());
-
-    duk_push_string(ctx, fileName.c_str());
-    duk_put_global_string(ctx, "object_script_path");
-    return 0;
-}
-
 void ScriptTestFixture::dukMockMetafile(
     duk_context* ctx,
-    const std::map<std::string, std::string>& props)
+    const std::map<std::string, std::string>& props,
+    const std::vector<std::pair<std::string, std::string>>& meta,
+    const std::map<std::string, std::string>& aux,
+    const std::map<std::string, std::string>& res)
 {
     duk_push_object(ctx);
     for (auto&& [name, value] : props) {
@@ -376,7 +205,7 @@ void ScriptTestFixture::addGlobalFunctions(
     const std::map<std::string_view, std::map<std::string_view, std::string_view>>& configDicts)
 {
 
-    for (auto&&[meta,str]: MetaEnumMapper::mt_keys) {
+    for (auto&& [meta, str] : MetaEnumMapper::mt_keys) {
         duk_push_lstring(ctx, str.data(), str.size());
         auto sym = mt_names.at(meta);
         duk_put_global_lstring(ctx, sym.data(), sym.size());
@@ -407,7 +236,7 @@ void ScriptTestFixture::addGlobalFunctions(
     if (configValues.empty()) {
         addConfig(
             ctx,
-            { { "/import/scripting/virtual-layout/attribute::audio-layout", audioLayout }, { "/import/scripting/virtual-layout/structured-layout/attribute::skip-chars", "" } },
+            { { "/import/scripting/virtual-layout/structured-layout/attribute::skip-chars", "" } },
             boxDefaults,
             configDicts);
     } else {
@@ -442,7 +271,6 @@ void ScriptTestFixture::addConfig(
             duk_put_prop_string(ctx, -2, key.data());
         }
         duk_put_prop_string(ctx, -2, dictName.data()); // dict
-
     }
 
     duk_push_object(ctx); // box-layout
@@ -467,31 +295,25 @@ void ScriptTestFixture::addConfig(
     duk_put_global_string(ctx, "config");
 }
 
-void ScriptTestFixture::executeScript(duk_context* ctx)
-{
-    duk_push_thread_stash(ctx, ctx);
-    duk_get_global_string(ctx, "script_under_test");
-    if (duk_is_function(ctx, -1)) {
-        if (duk_pcall(ctx, 0) != DUK_EXEC_SUCCESS) {
-            DukTestHelper::printError(ctx, "Failed to execute script ", scriptName);
-        }
-        duk_pop(ctx); // script_under_test
-    }
-}
-
 void ScriptTestFixture::callFunction(
     duk_context* ctx,
-    void(dukMockFunction)(duk_context* ctx, const std::map<std::string, std::string>& props),
+    DukMockFunction dukMockFunction,
     const std::map<std::string, std::string>& props,
+    const std::vector<std::pair<std::string, std::string>>& meta,
+    const std::map<std::string, std::string>& aux,
+    const std::map<std::string, std::string>& res,
+    const std::string& containerType,
     const std::string& rootPath)
 {
-    dukMockFunction(ctx, props);
-    duk_put_global_string(ctx, objectName.c_str());
-    // functionName(object, rootPath, autoScanId, containerType)
-    std::string containerType;
+    // functionName(object, container, rootPath, autoScanId, containerType)
+    if (functionName.empty()) {
+        std::cerr << "javascript function not set" << std::endl;
+        return;
+    }
+
     // Push function onto stack
     if (!duk_get_global_string(ctx, functionName.c_str()) || !duk_is_function(ctx, -1)) {
-        std::cerr << "javascript function not found: " << functionName << '\n';
+        std::cerr << "javascript function not found: " << functionName << std::endl;
         duk_pop(ctx);
         return;
     }
@@ -499,11 +321,11 @@ void ScriptTestFixture::callFunction(
     int narg = 0;
 
     // Push obj structure onto stack
-    dukMockFunction(ctx, props);
+    dukMockFunction(ctx, props, meta, aux, res);
     narg++;
 
     // Push obj structure onto stack (as container)
-    dukMockFunction(ctx, props);
+    dukMockFunction(ctx, props, meta, aux, res);
     narg++;
 
     // push rootPath onto stack
@@ -556,11 +378,11 @@ std::pair<std::string, int> ScriptTestFixture::getLastPath2(duk_context* ctx)
         if (pos > 0 && psize - length <= pos && pos < psize) {
             duk_push_string(ctx, (*i).c_str());
             duk_put_prop_index(ctx, dukArray, idx);
-	    idx++;
+            idx++;
         }
-	pos++;
+        pos++;
     }
-    return {inputPath, length};
+    return { inputPath, length };
 }
 
 std::string ScriptTestFixture::getLastPath(duk_context* ctx)
@@ -603,7 +425,7 @@ std::tuple<std::string, std::string> ScriptTestFixture::print2(duk_context* ctx)
 {
     std::string mode = duk_to_string(ctx, 0);
     std::string result = duk_to_string(ctx, 1);
-    return {mode, result};
+    return { mode, result };
 }
 
 std::string ScriptTestFixture::print(duk_context* ctx)
