@@ -4,7 +4,7 @@
 
     test_external_asx_playlist.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -25,7 +25,6 @@
 #include "cds/cds_objects.h"
 #include "exceptions.h"
 #include "upnp/upnp_common.h"
-#include "util/string_converter.h"
 #include "util/tools.h"
 
 #include "mock/common_script_mock.h"
@@ -43,9 +42,7 @@ class ExternalUrlAsxPlaylistTest : public CommonScriptTestFixture {
 public:
     ExternalUrlAsxPlaylistTest()
     {
-        scriptName = "playlists.js";
         functionName = "importPlaylist";
-        objectName = "playlist";
     }
 };
 
@@ -86,7 +83,7 @@ static duk_ret_t readXml(duk_context* ctx)
     } else if (root.next_sibling()) {
         root = root.next_sibling();
         node = root;
-    } else 
+    } else
         node = nullNode;
 
     std::ostringstream buf;
@@ -202,6 +199,6 @@ TEST_F(ExternalUrlAsxPlaylistTest, AddsVideoFromPlaylistWithExternalUrlPlaylistA
     EXPECT_CALL(*commonScriptMock, addCdsObject(IsIdenticalMap(asPlaylistChain), "43", UNDEFINED)).WillOnce(Return(0));
 
     addGlobalFunctions(ctx, js_global_functions, {}, playlistBox);
-    callFunction(ctx, dukMockPlaylist, {{"title", "Playlist Title"}, {"location", "/location/of/playlist.asx"}, {"mimetype", MIME_TYPE_ASX_PLAYLIST}});
+    callFunction(ctx, dukMockPlaylist, { { "title", "Playlist Title" }, { "location", "/location/of/playlist.asx" }, { "mimetype", MIME_TYPE_ASX_PLAYLIST } });
 }
 #endif
